/* properties-toolbar.c generated by valac 0.25.1.6-a1f05, the Vala compiler
 * generated from properties-toolbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <libgd/gd.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>


#define BOXES_TYPE_PROPERTIES_TOOLBAR (boxes_properties_toolbar_get_type ())
#define BOXES_PROPERTIES_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbar))
#define BOXES_PROPERTIES_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbarClass))
#define BOXES_IS_PROPERTIES_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR))
#define BOXES_IS_PROPERTIES_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_TOOLBAR))
#define BOXES_PROPERTIES_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbarClass))

typedef struct _BoxesPropertiesToolbar BoxesPropertiesToolbar;
typedef struct _BoxesPropertiesToolbarClass BoxesPropertiesToolbarClass;
typedef struct _BoxesPropertiesToolbarPrivate BoxesPropertiesToolbarPrivate;

#define BOXES_TYPE_EDITABLE_ENTRY (boxes_editable_entry_get_type ())
#define BOXES_EDITABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntry))
#define BOXES_EDITABLE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntryClass))
#define BOXES_IS_EDITABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EDITABLE_ENTRY))
#define BOXES_IS_EDITABLE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EDITABLE_ENTRY))
#define BOXES_EDITABLE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntryClass))

typedef struct _BoxesEditableEntry BoxesEditableEntry;
typedef struct _BoxesEditableEntryClass BoxesEditableEntryClass;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;

struct _BoxesPropertiesToolbar {
	GtkHeaderBar parent_instance;
	BoxesPropertiesToolbarPrivate * priv;
};

struct _BoxesPropertiesToolbarClass {
	GtkHeaderBarClass parent_class;
};

struct _BoxesPropertiesToolbarPrivate {
	GtkImage* back_image;
	BoxesEditableEntry* title_entry;
	BoxesAppWindow* window;
	BoxesCollectionItem* item;
	gulong item_name_id;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSelectionbar* selectionbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};


static gpointer boxes_properties_toolbar_parent_class = NULL;

GType boxes_properties_toolbar_get_type (void) G_GNUC_CONST;
GType boxes_editable_entry_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
#define BOXES_PROPERTIES_TOOLBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbarPrivate))
enum  {
	BOXES_PROPERTIES_TOOLBAR_DUMMY_PROPERTY
};
void boxes_properties_toolbar_setup_ui (BoxesPropertiesToolbar* self, BoxesAppWindow* window);
static void boxes_properties_toolbar_ui_state_changed (BoxesPropertiesToolbar* self);
static void _boxes_properties_toolbar_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_properties_toolbar_on_back_clicked (BoxesPropertiesToolbar* self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
static void _boxes_properties_toolbar_on_back_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_properties_toolbar_on_title_entry_changed (BoxesPropertiesToolbar* self);
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
const gchar* boxes_editable_entry_get_text (BoxesEditableEntry* self);
void boxes_collection_item_set_name (BoxesCollectionItem* self, const gchar* value);
static void _boxes_properties_toolbar_on_title_entry_changed_boxes_editable_entry_editing_done (BoxesEditableEntry* _sender, gpointer self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
static void ___lambda98_ (BoxesPropertiesToolbar* self);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
void boxes_editable_entry_set_text (BoxesEditableEntry* self, const gchar* value);
static void ____lambda98__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
BoxesPropertiesToolbar* boxes_properties_toolbar_new (void);
BoxesPropertiesToolbar* boxes_properties_toolbar_construct (GType object_type);
static GObject * boxes_properties_toolbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void boxes_properties_toolbar_finalize (GObject* obj);


static gpointer _g_object_ref0 (gpointer self) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	return self ? g_object_ref (self) : NULL;
#line 273 "properties-toolbar.c"
}


static void _boxes_properties_toolbar_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_properties_toolbar_ui_state_changed ((BoxesPropertiesToolbar*) self);
#line 280 "properties-toolbar.c"
}


void boxes_properties_toolbar_setup_ui (BoxesPropertiesToolbar* self, BoxesAppWindow* window) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_return_if_fail (window != NULL);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = window;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_g_object_unref0 (self->priv->window);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	self->priv->window = _tmp1_;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp2_ = window;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_signal_connect_object ((GObject*) _tmp2_, "notify::ui-state", (GCallback) _boxes_properties_toolbar_ui_state_changed_g_object_notify, self, 0);
#line 304 "properties-toolbar.c"
}


static void boxes_properties_toolbar_on_back_clicked (BoxesPropertiesToolbar* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesUIState _tmp2_ = 0;
	BoxesUIState _tmp3_ = 0;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = self->priv->window;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp1_ = self->priv->window;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp2_ = boxes_ui_get_previous_ui_state ((BoxesUI*) _tmp1_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp3_ = _tmp2_;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp0_, _tmp3_);
#line 325 "properties-toolbar.c"
}


static void _boxes_properties_toolbar_on_back_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_properties_toolbar_on_back_clicked ((BoxesPropertiesToolbar*) self);
#line 332 "properties-toolbar.c"
}


static void boxes_properties_toolbar_on_title_entry_changed (BoxesPropertiesToolbar* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesEditableEntry* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = self->priv->window;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp1_ = _tmp0_->current_item;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp2_ = self->priv->title_entry;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp3_ = boxes_editable_entry_get_text (_tmp2_);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp4_ = _tmp3_;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_collection_item_set_name (_tmp1_, _tmp4_);
#line 356 "properties-toolbar.c"
}


static void _boxes_properties_toolbar_on_title_entry_changed_boxes_editable_entry_editing_done (BoxesEditableEntry* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_properties_toolbar_on_title_entry_changed ((BoxesPropertiesToolbar*) self);
#line 363 "properties-toolbar.c"
}


static void ___lambda98_ (BoxesPropertiesToolbar* self) {
	BoxesEditableEntry* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = self->priv->title_entry;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp1_ = self->priv->item;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp2_ = boxes_collection_item_get_name (_tmp1_);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp3_ = _tmp2_;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_editable_entry_set_text (_tmp0_, _tmp3_);
#line 382 "properties-toolbar.c"
}


static void ____lambda98__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	___lambda98_ ((BoxesPropertiesToolbar*) self);
#line 389 "properties-toolbar.c"
}


static void boxes_properties_toolbar_ui_state_changed (BoxesPropertiesToolbar* self) {
	gulong _tmp0_ = 0UL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesUIState _tmp4_ = 0;
	BoxesUIState _tmp5_ = 0;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = self->priv->item_name_id;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	if (_tmp0_ != ((gulong) 0)) {
#line 404 "properties-toolbar.c"
		BoxesCollectionItem* _tmp1_ = NULL;
		gulong _tmp2_ = 0UL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp1_ = self->priv->item;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp2_ = self->priv->item_name_id;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		g_signal_handler_disconnect ((GObject*) _tmp1_, _tmp2_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		self->priv->item_name_id = (gulong) 0;
#line 415 "properties-toolbar.c"
	}
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp3_ = self->priv->window;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp4_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp3_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp5_ = _tmp4_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	if (_tmp5_ == BOXES_UI_STATE_PROPERTIES) {
#line 425 "properties-toolbar.c"
		BoxesAppWindow* _tmp6_ = NULL;
		BoxesCollectionItem* _tmp7_ = NULL;
		BoxesCollectionItem* _tmp8_ = NULL;
		BoxesCollectionItem* _tmp9_ = NULL;
		gulong _tmp10_ = 0UL;
		BoxesEditableEntry* _tmp11_ = NULL;
		BoxesCollectionItem* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp6_ = self->priv->window;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp7_ = _tmp6_->current_item;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp8_ = _g_object_ref0 (_tmp7_);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_g_object_unref0 (self->priv->item);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		self->priv->item = _tmp8_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp9_ = self->priv->item;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp10_ = g_signal_connect_object ((GObject*) _tmp9_, "notify::name", (GCallback) ____lambda98__g_object_notify, self, 0);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		self->priv->item_name_id = _tmp10_;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp11_ = self->priv->title_entry;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp12_ = self->priv->item;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp13_ = boxes_collection_item_get_name (_tmp12_);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp14_ = _tmp13_;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		boxes_editable_entry_set_text (_tmp11_, _tmp14_);
#line 461 "properties-toolbar.c"
	}
}


BoxesPropertiesToolbar* boxes_properties_toolbar_construct (GType object_type) {
	BoxesPropertiesToolbar * self = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	self = (BoxesPropertiesToolbar*) g_object_new (object_type, NULL);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	return self;
#line 472 "properties-toolbar.c"
}


BoxesPropertiesToolbar* boxes_properties_toolbar_new (void) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	return boxes_properties_toolbar_construct (BOXES_TYPE_PROPERTIES_TOOLBAR);
#line 479 "properties-toolbar.c"
}


static GObject * boxes_properties_toolbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesPropertiesToolbar * self;
	const gchar* _tmp0_ = NULL;
	GtkTextDirection _tmp1_ = 0;
	GtkImage* _tmp2_ = NULL;
	BoxesEditableEntry* _tmp3_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	parent_class = G_OBJECT_CLASS (boxes_properties_toolbar_parent_class);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbar);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp1_ = gtk_widget_get_direction ((GtkWidget*) self);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	if (_tmp1_ == GTK_TEXT_DIR_RTL) {
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp0_ = "go-previous-rtl-symbolic";
#line 503 "properties-toolbar.c"
	} else {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp0_ = "go-previous-symbolic";
#line 507 "properties-toolbar.c"
	}
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp2_ = self->priv->back_image;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_object_set (_tmp2_, "icon-name", _tmp0_, NULL);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp3_ = self->priv->title_entry;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_header_bar_set_custom_title ((GtkHeaderBar*) self, (GtkWidget*) _tmp3_);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	return obj;
#line 519 "properties-toolbar.c"
}


static void boxes_properties_toolbar_class_init (BoxesPropertiesToolbarClass * klass) {
	gint BoxesPropertiesToolbar_private_offset;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_properties_toolbar_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesPropertiesToolbarPrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_properties_toolbar_constructor;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_properties_toolbar_finalize;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	BoxesPropertiesToolbar_private_offset = g_type_class_get_instance_private_offset (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/properties-toolbar.ui");
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "back_image", FALSE, BoxesPropertiesToolbar_private_offset + G_STRUCT_OFFSET (BoxesPropertiesToolbarPrivate, back_image));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "title_entry", FALSE, BoxesPropertiesToolbar_private_offset + G_STRUCT_OFFSET (BoxesPropertiesToolbarPrivate, title_entry));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_back_clicked", G_CALLBACK(_boxes_properties_toolbar_on_back_clicked_gtk_button_clicked));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_title_entry_changed", G_CALLBACK(_boxes_properties_toolbar_on_title_entry_changed_boxes_editable_entry_editing_done));
#line 545 "properties-toolbar.c"
}


static void boxes_properties_toolbar_instance_init (BoxesPropertiesToolbar * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	self->priv = BOXES_PROPERTIES_TOOLBAR_GET_PRIVATE (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_type_ensure (BOXES_TYPE_EDITABLE_ENTRY);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 556 "properties-toolbar.c"
}


static void boxes_properties_toolbar_finalize (GObject* obj) {
	BoxesPropertiesToolbar * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbar);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_g_object_unref0 (self->priv->back_image);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_g_object_unref0 (self->priv->title_entry);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_g_object_unref0 (self->priv->window);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_g_object_unref0 (self->priv->item);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	G_OBJECT_CLASS (boxes_properties_toolbar_parent_class)->finalize (obj);
#line 574 "properties-toolbar.c"
}


GType boxes_properties_toolbar_get_type (void) {
	static volatile gsize boxes_properties_toolbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_toolbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesPropertiesToolbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_properties_toolbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesPropertiesToolbar), 0, (GInstanceInitFunc) boxes_properties_toolbar_instance_init, NULL };
		GType boxes_properties_toolbar_type_id;
		boxes_properties_toolbar_type_id = g_type_register_static (GTK_TYPE_HEADER_BAR, "BoxesPropertiesToolbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_properties_toolbar_type_id__volatile, boxes_properties_toolbar_type_id);
	}
	return boxes_properties_toolbar_type_id__volatile;
}



