/* libvirt-machine-properties.c generated by valac 0.25.1.6-a1f05, the Vala compiler
 * generated from libvirt-machine-properties.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <libcommon.h>
#include <glib/gstdio.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <config.h>
#include <pango/pango.h>
#include <osinfo/osinfo.h>


#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;

#define BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES (boxes_libvirt_machine_properties_get_type ())
#define BOXES_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachineProperties))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))

typedef struct _BoxesLibvirtMachineProperties BoxesLibvirtMachineProperties;
typedef struct _BoxesLibvirtMachinePropertiesClass BoxesLibvirtMachinePropertiesClass;
typedef struct _BoxesLibvirtMachinePropertiesPrivate BoxesLibvirtMachinePropertiesPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block37Data Block37Data;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define __vala_GVirDomainInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirDomainInfo_free (var), NULL)))
#define __vala_GVirNodeInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirNodeInfo_free (var), NULL)))
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

#define BOXES_TYPE_STRING_PROPERTY (boxes_string_property_get_type ())
#define BOXES_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_STRING_PROPERTY, BoxesStringProperty))
#define BOXES_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_STRING_PROPERTY, BoxesStringPropertyClass))
#define BOXES_IS_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_STRING_PROPERTY))
#define BOXES_IS_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_STRING_PROPERTY))
#define BOXES_STRING_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_STRING_PROPERTY, BoxesStringPropertyClass))

typedef struct _BoxesStringProperty BoxesStringProperty;
typedef struct _BoxesStringPropertyClass BoxesStringPropertyClass;
typedef struct _Block38Data Block38Data;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())

#define BOXES_TYPE_SIZE_PROPERTY (boxes_size_property_get_type ())
#define BOXES_SIZE_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIZE_PROPERTY, BoxesSizeProperty))
#define BOXES_SIZE_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIZE_PROPERTY, BoxesSizePropertyClass))
#define BOXES_IS_SIZE_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIZE_PROPERTY))
#define BOXES_IS_SIZE_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIZE_PROPERTY))
#define BOXES_SIZE_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIZE_PROPERTY, BoxesSizePropertyClass))

typedef struct _BoxesSizeProperty BoxesSizeProperty;
typedef struct _BoxesSizePropertyClass BoxesSizePropertyClass;
typedef struct _Block39Data Block39Data;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
typedef struct _Block40Data Block40Data;
typedef struct _Block41Data Block41Data;
typedef struct _Block42Data Block42Data;
typedef struct _Block43Data Block43Data;
typedef struct _Block44Data Block44Data;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;

#define BOXES_TYPE_UNATTENDED_INSTALLER (boxes_unattended_installer_get_type ())
#define BOXES_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller))
#define BOXES_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))
#define BOXES_IS_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_IS_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_UNATTENDED_INSTALLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))

typedef struct _BoxesUnattendedInstaller BoxesUnattendedInstaller;
typedef struct _BoxesUnattendedInstallerClass BoxesUnattendedInstallerClass;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;
typedef struct _BoxesUnattendedInstallerPrivate BoxesUnattendedInstallerPrivate;

#define BOXES_TYPE_UNATTENDED_SETUP_BOX (boxes_unattended_setup_box_get_type ())
#define BOXES_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBox))
#define BOXES_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))
#define BOXES_IS_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_IS_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_UNATTENDED_SETUP_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))

typedef struct _BoxesUnattendedSetupBox BoxesUnattendedSetupBox;
typedef struct _BoxesUnattendedSetupBoxClass BoxesUnattendedSetupBoxClass;
typedef struct _Block45Data Block45Data;
typedef struct _BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData;

#define BOXES_TYPE_OS_DATABASE (boxes_os_database_get_type ())
#define BOXES_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabase))
#define BOXES_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))
#define BOXES_IS_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_OS_DATABASE))
#define BOXES_IS_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_OS_DATABASE))
#define BOXES_OS_DATABASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))

typedef struct _BoxesOSDatabase BoxesOSDatabase;
typedef struct _BoxesOSDatabaseClass BoxesOSDatabaseClass;

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;
typedef struct _BoxesLibvirtMachinePropertiesGetOsForMachineData BoxesLibvirtMachinePropertiesGetOsForMachineData;
typedef struct _Block46Data Block46Data;
typedef struct _Block47Data Block47Data;
#define __vala_GVirStorageVolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStorageVolInfo_free (var), NULL)))
#define __vala_GVirStoragePoolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStoragePoolInfo_free (var), NULL)))
typedef struct _Block48Data Block48Data;
typedef struct _Block49Data Block49Data;

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

struct _BoxesLibvirtMachineProperties {
	GObject parent_instance;
	BoxesLibvirtMachinePropertiesPrivate * priv;
};

struct _BoxesLibvirtMachinePropertiesClass {
	GObjectClass parent_class;
};

struct _BoxesLibvirtMachinePropertiesPrivate {
	BoxesLibvirtMachine* machine;
};

struct _Block37Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* machine;
};

struct _Block38Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesStringProperty* name_property;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _Block39Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	gchar* log;
	GtkDialog* dialog;
};

struct _Block40Data {
	int _ref_count_;
	Block39Data * _data39_;
	GtkFileChooserDialog* chooser;
};

struct _Block41Data {
	int _ref_count_;
	Block40Data * _data40_;
	GtkMessageDialog* m;
};

struct _Block42Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesProperty* property;
};

struct _Block43Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesProperty* property;
};

struct _Block44Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	GtkLabel* label;
	gboolean empty;
	GtkLabel* button_label;
	GVirConfigDomainDisk* disk_config;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesUnattendedInstaller {
	BoxesInstallerMedia parent_instance;
	BoxesUnattendedInstallerPrivate * priv;
	BoxesUnattendedSetupBox* setup_box;
	GFile* disk_file;
	GFile* secondary_disk_file;
	GFile* kernel_file;
	GFile* initrd_file;
	OsinfoInstallConfig* config;
	OsinfoInstallScriptList* scripts;
};

struct _BoxesUnattendedInstallerClass {
	BoxesInstallerMediaClass parent_class;
};

struct _Block45Data {
	int _ref_count_;
	Block44Data * _data44_;
	GtkFileChooserDialog* dialog;
};

struct _BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachineProperties* self;
	BoxesSizeProperty* ram_property;
	BoxesSizeProperty* storage_property;
	gboolean _tmp0_;
	BoxesSizeProperty* _tmp1_;
	BoxesSizeProperty* _tmp2_;
	OsinfoOs* os;
	BoxesLibvirtMachine* _tmp3_;
	OsinfoOs* _tmp4_;
	OsinfoOs* _tmp5_;
	gchar* architecture;
	BoxesLibvirtMachine* _tmp6_;
	GVirConfigDomain* _tmp7_;
	GVirConfigDomain* _tmp8_;
	GVirConfigDomainOs* _tmp9_;
	GVirConfigDomainOs* _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	OsinfoResources* resources;
	OsinfoOs* _tmp14_;
	const gchar* _tmp15_;
	OsinfoResources* _tmp16_;
	OsinfoResources* _tmp17_;
	BoxesSizeProperty* _tmp18_;
	BoxesSizeProperty* _tmp19_;
	OsinfoResources* _tmp20_;
	gint64 _tmp21_;
	gint64 _tmp22_;
	BoxesSizeProperty* _tmp23_;
	BoxesSizeProperty* _tmp24_;
	OsinfoResources* _tmp25_;
	gint64 _tmp26_;
	gint64 _tmp27_;
};

typedef enum  {
	BOXES_OS_DATABASE_ERROR_NON_BOOTABLE,
	BOXES_OS_DATABASE_ERROR_DB_LOADING_FAILED,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_OS_ID,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_MEDIA_ID
} BoxesOSDatabaseError;
#define BOXES_OS_DATABASE_ERROR boxes_os_database_error_quark ()
struct _BoxesLibvirtMachinePropertiesGetOsForMachineData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* machine;
	OsinfoOs* result;
	gchar* os_id;
	BoxesLibvirtMachine* _tmp0_;
	GVirConfigDomain* _tmp1_;
	GVirConfigDomain* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	BoxesOSDatabase* os_db;
	BoxesMediaManager* _tmp5_;
	BoxesMediaManager* _tmp6_;
	BoxesOSDatabase* _tmp7_;
	BoxesOSDatabase* _tmp8_;
	BoxesOSDatabase* _tmp9_;
	BoxesOSDatabase* _tmp10_;
	OsinfoOs* _tmp11_;
	BoxesOSDatabase* _tmp12_;
	const gchar* _tmp13_;
	OsinfoOs* _tmp14_;
	OsinfoOs* _tmp15_;
	GError* _error_;
	const gchar* _tmp16_;
	GError* _tmp17_;
	const gchar* _tmp18_;
	GError * _inner_error_;
};

struct _Block46Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesSizeProperty* property;
};

struct _Block47Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesProperty* property;
	guint64 value;
};

struct _Block48Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	guint64 value;
};

struct _Block49Data {
	int _ref_count_;
	Block48Data * _data48_;
	guint64 size;
	GVirStoragePool* pool;
};


static gpointer boxes_libvirt_machine_properties_parent_class = NULL;
static BoxesIPropertiesProviderIface* boxes_libvirt_machine_properties_boxes_iproperties_provider_parent_iface = NULL;

GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_properties_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesPrivate))
enum  {
	BOXES_LIBVIRT_MACHINE_PROPERTIES_DUMMY_PROPERTY
};
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_MEGABYTES ((guint64) (1000 * 1000))
BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_new (BoxesLibvirtMachine* machine);
BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_construct (GType object_type, BoxesLibvirtMachine* machine);
static Block37Data* block37_data_ref (Block37Data* _data37_);
static void block37_data_unref (void * _userdata_);
static void __lambda101_ (Block37Data* _data37_);
static gboolean boxes_libvirt_machine_properties_try_change_name (BoxesLibvirtMachineProperties* self, const gchar* name);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
static void ___lambda101__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
void boxes_collection_item_set_name (BoxesCollectionItem* self, const gchar* value);
static void boxes_libvirt_machine_properties_try_enable_usb_redir (BoxesLibvirtMachineProperties* self, GError** error);
void boxes_vm_configurator_remove_usb_controllers (GVirConfigDomain* domain, GError** error);
void boxes_vm_configurator_add_usb_support (GVirConfigDomain* domain);
static void boxes_libvirt_machine_properties_try_enable_smartcard (BoxesLibvirtMachineProperties* self, GError** error);
void boxes_vm_configurator_add_smartcard_support (GVirConfigDomain* domain);
static gchar* boxes_libvirt_machine_properties_collect_logs (BoxesLibvirtMachineProperties* self);
GVirConnection* boxes_libvirt_machine_get_connection (BoxesLibvirtMachine* self);
static void _vala_GVirDomainInfo_free (GVirDomainInfo* self);
static void _vala_GVirNodeInfo_free (GVirNodeInfo* self);
const gchar* gvir_domain_state_to_string (GVirDomainState self);
GType boxes_display_get_type (void) G_GNUC_CONST;
BoxesDisplay* boxes_machine_get_display (BoxesMachine* self);
void boxes_display_collect_logs (BoxesDisplay* self, GString* builder);
static GList* boxes_libvirt_machine_properties_real_get_properties (BoxesIPropertiesProvider* base, BoxesPropertiesPage page, PropertyCreationFlag* flags);
gboolean boxes_machine_is_on (BoxesMachine* self);
gboolean boxes_libvirt_machine_update_display (BoxesLibvirtMachine* self, GError** error);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
GType boxes_string_property_get_type (void) G_GNUC_CONST;
static Block38Data* block38_data_ref (Block38Data* _data38_);
static void block38_data_unref (void * _userdata_);
BoxesStringProperty* boxes_iproperties_provider_add_string_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, const gchar* value);
void boxes_string_property_set_editable (BoxesStringProperty* self, gboolean value);
static gboolean ___lambda122_ (BoxesLibvirtMachineProperties* self, BoxesStringProperty* property, const gchar* name);
static gboolean ____lambda122__boxes_string_property_changed (BoxesStringProperty* _sender, const gchar* value, gpointer self);
static void ___lambda123_ (Block38Data* _data38_);
void boxes_string_property_set_text (BoxesStringProperty* self, const gchar* value);
static void ____lambda123__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
gchar* boxes_display_get_uri (BoxesDisplay* self);
GType boxes_size_property_get_type (void) G_GNUC_CONST;
static BoxesSizeProperty* boxes_libvirt_machine_properties_add_ram_property (BoxesLibvirtMachineProperties* self, GList** list);
static BoxesSizeProperty* boxes_libvirt_machine_properties_add_storage_property (BoxesLibvirtMachineProperties* self, GList** list);
static void boxes_libvirt_machine_properties_mark_recommended_resources (BoxesLibvirtMachineProperties* self, BoxesSizeProperty* ram_property, BoxesSizeProperty* storage_property, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_machine_properties_mark_recommended_resources_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_);
BoxesProperty* boxes_iproperties_provider_add_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, GtkWidget* widget, GtkWidget* extra_widget);
static void ___lambda128_ (BoxesLibvirtMachineProperties* self);
static Block39Data* block39_data_ref (Block39Data* _data39_);
static void block39_data_unref (void * _userdata_);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
BoxesAppWindow* boxes_machine_get_window (BoxesMachine* self);
static void __lambda129_ (Block39Data* _data39_, gint response_id);
static Block40Data* block40_data_ref (Block40Data* _data40_);
static void block40_data_unref (void * _userdata_);
static void ___lambda130_ (Block40Data* _data40_, gint response_id);
static Block41Data* block41_data_ref (Block41Data* _data41_);
static void block41_data_unref (void * _userdata_);
static void ____lambda131_ (Block41Data* _data41_);
static void _____lambda131__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static void ____lambda130__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static void ___lambda129__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static void ____lambda128__gtk_button_clicked (GtkButton* _sender, gpointer self);
const gchar* boxes_display_get_protocol (BoxesDisplay* self);
GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self);
static void boxes_libvirt_machine_properties_add_cdrom_property (BoxesLibvirtMachineProperties* self, GVirConfigDomainDisk* disk_config, GList** list);
static Block42Data* block42_data_ref (Block42Data* _data42_);
static void block42_data_unref (void * _userdata_);
static void ____lambda134_ (Block42Data* _data42_);
void boxes_libvirt_machine_update_domain_config (BoxesLibvirtMachine* self);
void boxes_property_set_reboot_required (BoxesProperty* self, gboolean value);
static void _____lambda134__gtk_button_clicked (GtkButton* _sender, gpointer self);
static Block43Data* block43_data_ref (Block43Data* _data43_);
static void block43_data_unref (void * _userdata_);
static void ____lambda135_ (Block43Data* _data43_);
static void _____lambda135__gtk_button_clicked (GtkButton* _sender, gpointer self);
static Block44Data* block44_data_ref (Block44Data* _data44_);
static void block44_data_unref (void * _userdata_);
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
BoxesVMCreator* boxes_libvirt_machine_get_vm_creator (BoxesLibvirtMachine* self);
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self);
GType boxes_unattended_installer_get_type (void) G_GNUC_CONST;
GType boxes_unattended_setup_box_get_type (void) G_GNUC_CONST;
gboolean boxes_unattended_setup_box_get_express_install (BoxesUnattendedSetupBox* self);
static void __lambda132_ (Block44Data* _data44_);
static Block45Data* block45_data_ref (Block45Data* _data45_);
static void block45_data_unref (void * _userdata_);
static void ___lambda133_ (Block45Data* _data45_, gint response);
static void ____lambda133__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static void ___lambda132__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_libvirt_machine_properties_update_ram_property (BoxesLibvirtMachineProperties* self, BoxesProperty* property);
static void boxes_libvirt_machine_properties_mark_recommended_resources_data_free (gpointer _data);
static gboolean boxes_libvirt_machine_properties_mark_recommended_resources_co (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_);
static void boxes_libvirt_machine_properties_get_os_for_machine (BoxesLibvirtMachineProperties* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
static OsinfoOs* boxes_libvirt_machine_properties_get_os_for_machine_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_);
static void boxes_libvirt_machine_properties_mark_recommended_resources_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
OsinfoResources* boxes_os_database_get_recommended_resources_for_os (OsinfoOs* os, const gchar* architecture);
void boxes_size_property_set_recommended (BoxesSizeProperty* self, guint64 value);
static void boxes_libvirt_machine_properties_get_os_for_machine_data_free (gpointer _data);
static gboolean boxes_libvirt_machine_properties_get_os_for_machine_co (BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_);
gchar* boxes_vm_configurator_get_os_id (GVirConfigDomain* domain);
GType boxes_os_database_get_type (void) G_GNUC_CONST;
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
BoxesMediaManager* boxes_media_manager_get_instance (void);
BoxesOSDatabase* boxes_media_manager_get_os_db (BoxesMediaManager* self);
void boxes_os_database_get_os_by_id (BoxesOSDatabase* self, const gchar* id, GAsyncReadyCallback _callback_, gpointer _user_data_);
GQuark boxes_os_database_error_quark (void);
OsinfoOs* boxes_os_database_get_os_by_id_finish (BoxesOSDatabase* self, GAsyncResult* _res_, GError** error);
static void boxes_libvirt_machine_properties_get_os_for_machine_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static Block46Data* block46_data_ref (Block46Data* _data46_);
static void block46_data_unref (void * _userdata_);
BoxesSizeProperty* boxes_iproperties_provider_add_size_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, guint64 size, guint64 min, guint64 max, guint64 step, GFormatSizeFlags format_flags);
gboolean boxes_vm_configurator_is_install_config (GVirConfigDomain* domain);
gboolean boxes_vm_configurator_is_live_config (GVirConfigDomain* domain);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
void boxes_property_set_sensitive (BoxesProperty* self, gboolean value);
static void boxes_libvirt_machine_properties_on_ram_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value);
static void _boxes_libvirt_machine_properties_on_ram_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self);
static void ___lambda125_ (Block46Data* _data46_);
static void ____lambda125__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static Block47Data* block47_data_ref (Block47Data* _data47_);
static void block47_data_unref (void * _userdata_);
static gboolean __lambda124_ (Block47Data* _data47_);
static gboolean ___lambda124__gsource_func (gpointer self);
void boxes_property_set_deferred_change (BoxesProperty* self, GSourceFunc value, gpointer value_target, GDestroyNotify value_target_destroy_notify);
gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self);
GVirStorageVol* boxes_libvirt_machine_get_storage_volume (BoxesLibvirtMachine* self);
GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection);
static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self);
static guint64 boxes_libvirt_machine_properties_get_minimum_disk_size (BoxesLibvirtMachineProperties* self, GError** error);
static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self);
void boxes_property_set_defer_interval (BoxesProperty* self, guint value);
static void boxes_libvirt_machine_properties_on_storage_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value);
static void _boxes_libvirt_machine_properties_on_storage_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self);
static Block48Data* block48_data_ref (Block48Data* _data48_);
static void block48_data_unref (void * _userdata_);
static gboolean __lambda126_ (Block48Data* _data48_);
gboolean boxes_machine_is_running (BoxesMachine* self);
GVirDomainDisk* boxes_libvirt_machine_get_domain_disk (BoxesLibvirtMachine* self, GError** error);
static Block49Data* block49_data_ref (Block49Data* _data49_);
static void block49_data_unref (void * _userdata_);
static void _____lambda127_ (Block49Data* _data49_, GObject* obj, GAsyncResult* res);
static void ______lambda127__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void boxes_libvirt_machine_properties_resize_storage_volume (BoxesLibvirtMachineProperties* self, guint64 size, GError** error);
static gboolean ___lambda126__gsource_func (gpointer self);
OsinfoResources* boxes_os_database_get_minimum_resources_for_os (OsinfoOs* os, const gchar* architecture);
OsinfoResources* boxes_os_database_get_default_resources (void);
void boxes_libvirt_machine_set_storage_volume (BoxesLibvirtMachine* self, GVirStorageVol* value);
static void boxes_libvirt_machine_properties_finalize (GObject* obj);


static gpointer _g_object_ref0 (gpointer self) {
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return self ? g_object_ref (self) : NULL;
#line 710 "libvirt-machine-properties.c"
}


static Block37Data* block37_data_ref (Block37Data* _data37_) {
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data37_->_ref_count_);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data37_;
#line 719 "libvirt-machine-properties.c"
}


static void block37_data_unref (void * _userdata_) {
	Block37Data* _data37_;
	_data37_ = (Block37Data*) _userdata_;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data37_->_ref_count_)) {
#line 728 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data37_->self;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data37_->machine);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block37Data, _data37_);
#line 738 "libvirt-machine-properties.c"
	}
}


static void __lambda101_ (Block37Data* _data37_) {
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data37_->self;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data37_->machine;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp0_);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_try_change_name (self, _tmp2_);
#line 758 "libvirt-machine-properties.c"
}


static void ___lambda101__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda101_ (self);
#line 765 "libvirt-machine-properties.c"
}


BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_construct (GType object_type, BoxesLibvirtMachine* machine) {
	BoxesLibvirtMachineProperties * self = NULL;
	Block37Data* _data37_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	BoxesLibvirtMachine* _tmp3_ = NULL;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_ = g_slice_new0 (Block37Data);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_->_ref_count_ = 1;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = machine;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data37_->machine);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_->machine = _tmp1_;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = (BoxesLibvirtMachineProperties*) g_object_new (object_type, NULL);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_->self = g_object_ref (self);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _data37_->machine;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self->priv->machine = _tmp2_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _data37_->machine;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_data ((GObject*) _tmp3_, "notify::name", (GCallback) ___lambda101__g_object_notify, block37_data_ref (_data37_), (GClosureNotify) block37_data_unref, 0);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block37_data_unref (_data37_);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_ = NULL;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return self;
#line 808 "libvirt-machine-properties.c"
}


BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_new (BoxesLibvirtMachine* machine) {
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return boxes_libvirt_machine_properties_construct (BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, machine);
#line 815 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_try_change_name (BoxesLibvirtMachineProperties* self, const gchar* name) {
	gboolean result = FALSE;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (name != NULL, FALSE);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp0_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = name;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_strcmp0 (_tmp2_, _tmp3_) == 0) {
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = FALSE;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 844 "libvirt-machine-properties.c"
	}
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp4_ = NULL;
		GVirDomain* _tmp5_ = NULL;
		GVirDomain* _tmp6_ = NULL;
		GVirConfigDomain* _tmp7_ = NULL;
		GVirConfigDomain* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		BoxesLibvirtMachine* _tmp10_ = NULL;
		GVirDomain* _tmp11_ = NULL;
		GVirDomain* _tmp12_ = NULL;
		GVirConfigDomain* _tmp13_ = NULL;
		BoxesLibvirtMachine* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = self->priv->machine;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = boxes_libvirt_machine_get_domain (_tmp4_);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = gvir_domain_get_config (_tmp6_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp7_;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 872 "libvirt-machine-properties.c"
			goto __catch27_g_error;
		}
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = config;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = name;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_set_title (_tmp8_, _tmp9_);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = self->priv->machine;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = boxes_libvirt_machine_get_domain (_tmp10_);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = _tmp11_;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = config;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_domain_set_config (_tmp12_, _tmp13_, &_inner_error_);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 895 "libvirt-machine-properties.c"
			goto __catch27_g_error;
		}
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = self->priv->machine;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = name;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_collection_item_set_name ((BoxesCollectionItem*) _tmp14_, _tmp15_);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = TRUE;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 910 "libvirt-machine-properties.c"
	}
	goto __finally27;
	__catch27_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp16_ = NULL;
		GVirDomain* _tmp17_ = NULL;
		GVirDomain* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
		GError* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = self->priv->machine;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = boxes_libvirt_machine_get_domain (_tmp16_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = _tmp17_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = gvir_domain_get_name (_tmp18_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = name;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = _error_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = _tmp21_->message;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:32: Failed to change title of box '%s'" \
" to '%s': %s", _tmp19_, _tmp20_, _tmp22_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = FALSE;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 949 "libvirt-machine-properties.c"
	}
	__finally27:
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_inner_error_);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 958 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_try_enable_usb_redir (BoxesLibvirtMachineProperties* self, GError** error) {
	GVirConfigDomain* config = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirDomain* _tmp1_ = NULL;
	GVirDomain* _tmp2_ = NULL;
	GVirConfigDomain* _tmp3_ = NULL;
	GVirConfigDomain* _tmp4_ = NULL;
	GVirConfigDomain* _tmp5_ = NULL;
	BoxesLibvirtMachine* _tmp6_ = NULL;
	GVirDomain* _tmp7_ = NULL;
	GVirDomain* _tmp8_ = NULL;
	GVirConfigDomain* _tmp9_ = NULL;
	GError * _inner_error_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = gvir_domain_get_config (_tmp2_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	config = _tmp3_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 993 "libvirt-machine-properties.c"
	}
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = config;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_vm_configurator_remove_usb_controllers (_tmp4_, &_inner_error_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 1007 "libvirt-machine-properties.c"
	}
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = config;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_vm_configurator_add_usb_support (_tmp5_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = self->priv->machine;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = boxes_libvirt_machine_get_domain (_tmp6_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = _tmp7_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = config;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gvir_domain_set_config (_tmp8_, _tmp9_, &_inner_error_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 1031 "libvirt-machine-properties.c"
	}
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (config);
#line 1035 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_try_enable_smartcard (BoxesLibvirtMachineProperties* self, GError** error) {
	GVirConfigDomain* config = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirDomain* _tmp1_ = NULL;
	GVirDomain* _tmp2_ = NULL;
	GVirConfigDomain* _tmp3_ = NULL;
	GVirConfigDomain* _tmp4_ = NULL;
	BoxesLibvirtMachine* _tmp5_ = NULL;
	GVirDomain* _tmp6_ = NULL;
	GVirDomain* _tmp7_ = NULL;
	GVirConfigDomain* _tmp8_ = NULL;
	GError * _inner_error_ = NULL;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = gvir_domain_get_config (_tmp2_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	config = _tmp3_;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 1069 "libvirt-machine-properties.c"
	}
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = config;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_vm_configurator_add_smartcard_support (_tmp4_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = self->priv->machine;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = boxes_libvirt_machine_get_domain (_tmp5_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = _tmp6_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = config;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gvir_domain_set_config (_tmp7_, _tmp8_, &_inner_error_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 1093 "libvirt-machine-properties.c"
	}
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (config);
#line 1097 "libvirt-machine-properties.c"
}


static void _vala_GVirDomainInfo_free (GVirDomainInfo* self) {
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_domain_info_get_type (), self);
#line 1104 "libvirt-machine-properties.c"
}


static void _vala_GVirNodeInfo_free (GVirNodeInfo* self) {
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_node_info_get_type (), self);
#line 1111 "libvirt-machine-properties.c"
}


static gchar* boxes_libvirt_machine_properties_collect_logs (BoxesLibvirtMachineProperties* self) {
	gchar* result = NULL;
	GString* builder = NULL;
	GString* _tmp0_ = NULL;
	GString* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	GVirDomain* _tmp3_ = NULL;
	GVirDomain* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	GString* _tmp6_ = NULL;
	BoxesLibvirtMachine* _tmp7_ = NULL;
	GVirDomain* _tmp8_ = NULL;
	GVirDomain* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	BoxesLibvirtMachine* _tmp12_ = NULL;
	GVirDomain* _tmp13_ = NULL;
	GVirDomain* _tmp14_ = NULL;
	gboolean _tmp15_ = FALSE;
	GString* _tmp16_ = NULL;
	BoxesLibvirtMachine* _tmp43_ = NULL;
	BoxesDisplay* _tmp44_ = NULL;
	BoxesDisplay* _tmp45_ = NULL;
	GString* _tmp74_ = NULL;
	const gchar* _tmp75_ = NULL;
	gchar* _tmp76_ = NULL;
	GError * _inner_error_ = NULL;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = g_string_new ("");
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	builder = _tmp0_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = builder;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = self->priv->machine;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = boxes_libvirt_machine_get_domain (_tmp2_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _tmp3_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = gvir_domain_get_name (_tmp4_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_string_append_printf (_tmp1_, "Domain: %s\n", _tmp5_);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = builder;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = self->priv->machine;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = boxes_libvirt_machine_get_domain (_tmp7_);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = _tmp8_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = gvir_domain_get_uuid (_tmp9_);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_string_append_printf (_tmp6_, "UUID: %s\n", _tmp10_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp12_ = self->priv->machine;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = boxes_libvirt_machine_get_domain (_tmp12_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp14_ = _tmp13_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp15_ = gvir_domain_get_persistent (_tmp14_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp15_) {
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = "yes";
#line 1184 "libvirt-machine-properties.c"
	} else {
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = "no";
#line 1188 "libvirt-machine-properties.c"
	}
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp16_ = builder;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_string_append_printf (_tmp16_, "Persistent: %s\n", _tmp11_);
#line 1194 "libvirt-machine-properties.c"
	{
		GVirDomainInfo* info = NULL;
		BoxesLibvirtMachine* _tmp17_ = NULL;
		GVirDomain* _tmp18_ = NULL;
		GVirDomain* _tmp19_ = NULL;
		GVirDomainInfo* _tmp20_ = NULL;
		GString* _tmp21_ = NULL;
		GVirDomainInfo* _tmp22_ = NULL;
		guint64 _tmp23_ = 0ULL;
		GString* _tmp24_ = NULL;
		GVirDomainInfo* _tmp25_ = NULL;
		guint64 _tmp26_ = 0ULL;
		GVirNodeInfo* _tmp27_ = NULL;
		BoxesLibvirtMachine* _tmp28_ = NULL;
		GVirConnection* _tmp29_ = NULL;
		GVirConnection* _tmp30_ = NULL;
		GVirNodeInfo* _tmp31_ = NULL;
		GString* _tmp32_ = NULL;
		GVirNodeInfo* _tmp33_ = NULL;
		GVirNodeInfo* _tmp34_ = NULL;
		gulong _tmp35_ = 0UL;
		GString* _tmp36_ = NULL;
		GVirDomainInfo* _tmp37_ = NULL;
		guint16 _tmp38_ = 0U;
		GString* _tmp39_ = NULL;
		GVirDomainInfo* _tmp40_ = NULL;
		GVirDomainState _tmp41_ = 0;
		GEnumValue* _tmp42_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = self->priv->machine;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = boxes_libvirt_machine_get_domain (_tmp17_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = gvir_domain_get_info (_tmp19_, &_inner_error_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		info = _tmp20_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1235 "libvirt-machine-properties.c"
			goto __catch28_g_error;
		}
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = builder;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = info;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = _tmp22_->cpuTime;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp21_, "Cpu time: %" G_GINT64_MODIFIER "d\n", _tmp23_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = builder;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = info;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = _tmp25_->memory;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp24_, "Memory: %" G_GINT64_MODIFIER "d KiB\n", _tmp26_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = self->priv->machine;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = boxes_libvirt_machine_get_connection (_tmp28_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = _tmp29_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = gvir_connection_get_node_info (_tmp30_, &_inner_error_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = _tmp31_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirDomainInfo_free0 (info);
#line 1268 "libvirt-machine-properties.c"
			goto __catch28_g_error;
		}
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = builder;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp33_ = _tmp27_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = NULL;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp34_ = _tmp33_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp35_ = _tmp34_->memory;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp32_, "Max memory: %" G_GINT64_MODIFIER "d KiB\n", _tmp35_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirNodeInfo_free0 (_tmp34_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp36_ = builder;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp37_ = info;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp38_ = _tmp37_->nrVirtCpu;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp36_, "CPUs: %d\n", (gint) _tmp38_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp39_ = builder;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp40_ = info;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp41_ = _tmp40_->state;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp42_ = g_enum_get_value (g_type_class_ref (gvir_domain_state_get_type ()), _tmp41_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp39_, "State: %s\n", (_tmp42_ != NULL) ? _tmp42_->value_name : NULL);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirNodeInfo_free0 (_tmp27_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirDomainInfo_free0 (info);
#line 1307 "libvirt-machine-properties.c"
	}
	goto __finally28;
	__catch28_g_error:
	{
		GError* e = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		e = _inner_error_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (e);
#line 1319 "libvirt-machine-properties.c"
	}
	__finally28:
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_string_free0 (builder);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return NULL;
#line 1332 "libvirt-machine-properties.c"
	}
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp43_ = self->priv->machine;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp44_ = boxes_machine_get_display ((BoxesMachine*) _tmp43_);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp45_ = _tmp44_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp45_ != NULL) {
#line 1342 "libvirt-machine-properties.c"
		BoxesLibvirtMachine* _tmp46_ = NULL;
		BoxesDisplay* _tmp47_ = NULL;
		BoxesDisplay* _tmp48_ = NULL;
		GString* _tmp49_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp46_ = self->priv->machine;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp47_ = boxes_machine_get_display ((BoxesMachine*) _tmp46_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp48_ = _tmp47_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp49_ = builder;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_display_collect_logs (_tmp48_, _tmp49_);
#line 1357 "libvirt-machine-properties.c"
	}
	{
		GVirConfigDomain* conf = NULL;
		BoxesLibvirtMachine* _tmp50_ = NULL;
		GVirDomain* _tmp51_ = NULL;
		GVirDomain* _tmp52_ = NULL;
		GVirConfigDomain* _tmp53_ = NULL;
		GString* _tmp54_ = NULL;
		GString* _tmp55_ = NULL;
		GString* _tmp56_ = NULL;
		gchar* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		GString* _tmp59_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp50_ = self->priv->machine;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp51_ = boxes_libvirt_machine_get_domain (_tmp50_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp52_ = _tmp51_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp53_ = gvir_domain_get_config (_tmp52_, (guint) GVIR_DOMAIN_XML_NONE, &_inner_error_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		conf = _tmp53_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1383 "libvirt-machine-properties.c"
			goto __catch29_g_error;
		}
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp54_ = builder;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp54_, "\nDomain config:\n");
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp55_ = builder;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp55_, "------------------------------------------------------------\n");
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp56_ = builder;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp57_ = gvir_config_object_to_xml ((GVirConfigObject*) conf);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp58_ = _tmp57_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append (_tmp56_, _tmp58_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp58_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp59_ = builder;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp59_, "%s", "\n" "------------------------------------------------------------\n");
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (conf);
#line 1410 "libvirt-machine-properties.c"
	}
	goto __finally29;
	__catch29_g_error:
	{
		GError* _error_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 1422 "libvirt-machine-properties.c"
	}
	__finally29:
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_string_free0 (builder);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return NULL;
#line 1435 "libvirt-machine-properties.c"
	}
	{
		gchar* logfile = NULL;
		const gchar* _tmp60_ = NULL;
		BoxesLibvirtMachine* _tmp61_ = NULL;
		GVirDomain* _tmp62_ = NULL;
		GVirDomain* _tmp63_ = NULL;
		const gchar* _tmp64_ = NULL;
		gchar* _tmp65_ = NULL;
		gchar* _tmp66_ = NULL;
		gchar* _tmp67_ = NULL;
		gchar* _tmp68_ = NULL;
		gchar* data = NULL;
		gchar* _tmp69_ = NULL;
		GString* _tmp70_ = NULL;
		GString* _tmp71_ = NULL;
		GString* _tmp72_ = NULL;
		GString* _tmp73_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp60_ = g_get_user_cache_dir ();
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp61_ = self->priv->machine;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp62_ = boxes_libvirt_machine_get_domain (_tmp61_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp63_ = _tmp62_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp64_ = gvir_domain_get_name (_tmp63_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp65_ = g_strconcat (_tmp64_, ".log", NULL);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp66_ = _tmp65_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp67_ = g_build_filename (_tmp60_, "libvirt/qemu/log", _tmp66_, NULL);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp68_ = _tmp67_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp66_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		logfile = _tmp68_;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_file_get_contents (logfile, &_tmp69_, NULL, &_inner_error_);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (data);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		data = _tmp69_;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (data);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (logfile);
#line 1488 "libvirt-machine-properties.c"
			goto __catch30_g_error;
		}
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp70_ = builder;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp70_, "\nQEMU log:\n");
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp71_ = builder;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp71_, "------------------------------------------------------------\n");
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp72_ = builder;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append (_tmp72_, data);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp73_ = builder;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp73_, "------------------------------------------------------------\n");
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (data);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (logfile);
#line 1511 "libvirt-machine-properties.c"
	}
	goto __finally30;
	__catch30_g_error:
	{
		GError* e = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		e = _inner_error_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (e);
#line 1523 "libvirt-machine-properties.c"
	}
	__finally30:
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_string_free0 (builder);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return NULL;
#line 1536 "libvirt-machine-properties.c"
	}
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp74_ = builder;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp75_ = _tmp74_->str;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp76_ = g_strdup (_tmp75_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = _tmp76_;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_string_free0 (builder);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 1550 "libvirt-machine-properties.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1557 "libvirt-machine-properties.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_list_free (self);
#line 1566 "libvirt-machine-properties.c"
}


static Block38Data* block38_data_ref (Block38Data* _data38_) {
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data38_->_ref_count_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data38_;
#line 1575 "libvirt-machine-properties.c"
}


static void block38_data_unref (void * _userdata_) {
	Block38Data* _data38_;
	_data38_ = (Block38Data*) _userdata_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data38_->_ref_count_)) {
#line 1584 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data38_->self;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data38_->name_property);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block38Data, _data38_);
#line 1594 "libvirt-machine-properties.c"
	}
}


static gboolean ___lambda122_ (BoxesLibvirtMachineProperties* self, BoxesStringProperty* property, const gchar* name) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (property != NULL, FALSE);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (name != NULL, FALSE);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = name;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_properties_try_change_name (self, _tmp0_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = _tmp1_;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 1615 "libvirt-machine-properties.c"
}


static gboolean ____lambda122__boxes_string_property_changed (BoxesStringProperty* _sender, const gchar* value, gpointer self) {
	gboolean result;
	result = ___lambda122_ ((BoxesLibvirtMachineProperties*) self, _sender, value);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 1624 "libvirt-machine-properties.c"
}


static void ___lambda123_ (Block38Data* _data38_) {
	BoxesLibvirtMachineProperties* self;
	BoxesStringProperty* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data38_->self;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data38_->name_property;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp1_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_string_property_set_text (_tmp0_, _tmp3_);
#line 1646 "libvirt-machine-properties.c"
}


static void ____lambda123__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda123_ (self);
#line 1653 "libvirt-machine-properties.c"
}


static Block39Data* block39_data_ref (Block39Data* _data39_) {
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data39_->_ref_count_);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data39_;
#line 1662 "libvirt-machine-properties.c"
}


static void block39_data_unref (void * _userdata_) {
	Block39Data* _data39_;
	_data39_ = (Block39Data*) _userdata_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data39_->_ref_count_)) {
#line 1671 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data39_->self;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data39_->dialog);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data39_->log);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block39Data, _data39_);
#line 1683 "libvirt-machine-properties.c"
	}
}


static Block40Data* block40_data_ref (Block40Data* _data40_) {
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data40_->_ref_count_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data40_;
#line 1693 "libvirt-machine-properties.c"
}


static void block40_data_unref (void * _userdata_) {
	Block40Data* _data40_;
	_data40_ = (Block40Data*) _userdata_;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data40_->_ref_count_)) {
#line 1702 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data40_->_data39_->self;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data40_->chooser);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block39_data_unref (_data40_->_data39_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data40_->_data39_ = NULL;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block40Data, _data40_);
#line 1714 "libvirt-machine-properties.c"
	}
}


static guint8* string_get_data (const gchar* self, int* result_length1) {
	guint8* result;
	guint8* res = NULL;
	gint res_length1 = 0;
	gint _res_size_ = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	guint8* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	guint8* _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
#line 1300 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1301 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	res = (guint8*) self;
#line 1301 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	res_length1 = -1;
#line 1301 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_res_size_ = res_length1;
#line 1302 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1302 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1302 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	res_length1 = (gint) _tmp1_;
#line 1302 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp2_ = res_length1;
#line 1303 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp3_ = res;
#line 1303 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp3__length1 = res_length1;
#line 1303 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp4_ = _tmp3_;
#line 1303 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp4__length1 = _tmp3__length1;
#line 1303 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (result_length1) {
#line 1303 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		*result_length1 = _tmp4__length1;
#line 1759 "libvirt-machine-properties.c"
	}
#line 1303 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 1303 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	return result;
#line 1765 "libvirt-machine-properties.c"
}


static Block41Data* block41_data_ref (Block41Data* _data41_) {
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data41_->_ref_count_);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data41_;
#line 1774 "libvirt-machine-properties.c"
}


static void block41_data_unref (void * _userdata_) {
	Block41Data* _data41_;
	_data41_ = (Block41Data*) _userdata_;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data41_->_ref_count_)) {
#line 1783 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data41_->_data40_->_data39_->self;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data41_->m);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block40_data_unref (_data41_->_data40_);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data41_->_data40_ = NULL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block41Data, _data41_);
#line 1795 "libvirt-machine-properties.c"
	}
}


static void ____lambda131_ (Block41Data* _data41_) {
	Block40Data* _data40_;
	Block39Data* _data39_;
	BoxesLibvirtMachineProperties* self;
	GtkMessageDialog* _tmp0_ = NULL;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data40_ = _data41_->_data40_;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data39_ = _data40_->_data39_;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data39_->self;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data41_->m;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_destroy ((GtkWidget*) _tmp0_);
#line 1815 "libvirt-machine-properties.c"
}


static void _____lambda131__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	____lambda131_ (self);
#line 1822 "libvirt-machine-properties.c"
}


static void ___lambda130_ (Block40Data* _data40_, gint response_id) {
	Block39Data* _data39_;
	BoxesLibvirtMachineProperties* self;
	gint _tmp0_ = 0;
	GError * _inner_error_ = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data39_ = _data40_->_data39_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data39_->self;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = response_id;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_ == ((gint) GTK_RESPONSE_OK)) {
#line 1839 "libvirt-machine-properties.c"
		GFile* file = NULL;
		GtkFileChooserDialog* _tmp1_ = NULL;
		GFile* _tmp2_ = NULL;
		GFile* _tmp3_ = NULL;
		GtkFileChooserDialog* _tmp17_ = NULL;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _data40_->chooser;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = gtk_file_chooser_get_file ((GtkFileChooser*) _tmp1_);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _g_object_ref0 (_tmp2_);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		file = _tmp3_;
#line 1853 "libvirt-machine-properties.c"
		{
			GFile* _tmp4_ = NULL;
			guint8* _tmp5_ = NULL;
			gint _tmp5__length1 = 0;
			guint8* _tmp6_ = NULL;
			gint _tmp6__length1 = 0;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp4_ = file;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp5_ = string_get_data (_data39_->log, &_tmp5__length1);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6_ = _tmp5_;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6__length1 = _tmp5__length1;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_file_replace_contents (_tmp4_, _tmp6_, (gsize) _tmp6__length1, NULL, FALSE, G_FILE_CREATE_REPLACE_DESTINATION, NULL, NULL, &_inner_error_);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1872 "libvirt-machine-properties.c"
				goto __catch32_g_error;
			}
		}
		goto __finally32;
		__catch32_g_error:
		{
			GError* e = NULL;
			Block41Data* _data41_;
			GtkFileChooserDialog* _tmp7_ = NULL;
			const gchar* _tmp8_ = NULL;
			GError* _tmp9_ = NULL;
			const gchar* _tmp10_ = NULL;
			gchar* _tmp11_ = NULL;
			gchar* _tmp12_ = NULL;
			GtkMessageDialog* _tmp13_ = NULL;
			GtkMessageDialog* _tmp14_ = NULL;
			GtkMessageDialog* _tmp15_ = NULL;
			GtkMessageDialog* _tmp16_ = NULL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			e = _inner_error_;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_inner_error_ = NULL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data41_ = g_slice_new0 (Block41Data);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data41_->_ref_count_ = 1;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data41_->_data40_ = block40_data_ref (_data40_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp7_ = _data40_->chooser;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp8_ = _ ("Error saving: %s");
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp9_ = e;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = _tmp9_->message;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = g_strdup_printf (_tmp8_, _tmp10_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp12_ = _tmp11_;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp13_ = (GtkMessageDialog*) gtk_message_dialog_new ((GtkWindow*) _tmp7_, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _tmp12_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_ref_sink (_tmp13_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp14_ = _tmp13_;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp12_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data41_->m = _tmp14_;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp15_ = _data41_->m;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_widget_show_all ((GtkWidget*) _tmp15_);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = _data41_->m;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_data ((GtkDialog*) _tmp16_, "response", (GCallback) _____lambda131__gtk_dialog_response, block41_data_ref (_data41_), (GClosureNotify) block41_data_unref, 0);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_error_free0 (e);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			block41_data_unref (_data41_);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data41_ = NULL;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (file);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 1941 "libvirt-machine-properties.c"
		}
		__finally32:
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (file);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_inner_error_);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 1954 "libvirt-machine-properties.c"
		}
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _data40_->chooser;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_widget_destroy ((GtkWidget*) _tmp17_);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (file);
#line 1962 "libvirt-machine-properties.c"
	} else {
		GtkFileChooserDialog* _tmp18_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = _data40_->chooser;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_widget_destroy ((GtkWidget*) _tmp18_);
#line 1969 "libvirt-machine-properties.c"
	}
}


static void ____lambda130__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda130_ (self, response_id);
#line 1977 "libvirt-machine-properties.c"
}


static void __lambda129_ (Block39Data* _data39_, gint response_id) {
	BoxesLibvirtMachineProperties* self;
	gint _tmp0_ = 0;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data39_->self;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = response_id;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_ == 100) {
#line 1990 "libvirt-machine-properties.c"
		Block40Data* _data40_;
		const gchar* _tmp1_ = NULL;
		BoxesLibvirtMachine* _tmp2_ = NULL;
		BoxesAppWindow* _tmp3_ = NULL;
		BoxesAppWindow* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		GtkFileChooserDialog* _tmp6_ = NULL;
		GtkFileChooserDialog* _tmp7_ = NULL;
		GtkFileChooserDialog* _tmp8_ = NULL;
		GtkFileChooserDialog* _tmp9_ = NULL;
		GtkFileChooserDialog* _tmp10_ = NULL;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data40_ = g_slice_new0 (Block40Data);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data40_->_ref_count_ = 1;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data40_->_data39_ = block39_data_ref (_data39_);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _ ("Save log");
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = self->priv->machine;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = boxes_machine_get_window ((BoxesMachine*) _tmp2_);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = _tmp3_;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _ ("_Save");
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (_tmp1_, (GtkWindow*) _tmp4_, GTK_FILE_CHOOSER_ACTION_SAVE, _tmp5_, GTK_RESPONSE_OK, NULL);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_ref_sink (_tmp6_);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data40_->chooser = _tmp6_;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = _data40_->chooser;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_chooser_set_local_only ((GtkFileChooser*) _tmp7_, FALSE);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _data40_->chooser;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_chooser_set_do_overwrite_confirmation ((GtkFileChooser*) _tmp8_, TRUE);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = _data40_->chooser;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_connect_data ((GtkDialog*) _tmp9_, "response", (GCallback) ____lambda130__gtk_dialog_response, block40_data_ref (_data40_), (GClosureNotify) block40_data_unref, 0);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _data40_->chooser;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_widget_show_all ((GtkWidget*) _tmp10_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block40_data_unref (_data40_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data40_ = NULL;
#line 2044 "libvirt-machine-properties.c"
	} else {
		gint _tmp11_ = 0;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = response_id;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp11_ == 101) {
#line 2051 "libvirt-machine-properties.c"
			GdkDisplay* _tmp12_ = NULL;
			GtkClipboard* _tmp13_ = NULL;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp12_ = gtk_widget_get_display ((GtkWidget*) _data39_->dialog);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp13_ = gtk_clipboard_get_for_display (_tmp12_, GDK_SELECTION_CLIPBOARD);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_clipboard_set_text (_tmp13_, _data39_->log, -1);
#line 2060 "libvirt-machine-properties.c"
		} else {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_widget_destroy ((GtkWidget*) _data39_->dialog);
#line 2064 "libvirt-machine-properties.c"
		}
	}
}


static void ___lambda129__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda129_ (self, response_id);
#line 2073 "libvirt-machine-properties.c"
}


static void ___lambda128_ (BoxesLibvirtMachineProperties* self) {
	Block39Data* _data39_;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesAppWindow* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	GtkDialog* _tmp8_ = NULL;
	GtkTextView* text = NULL;
	GtkTextView* _tmp9_ = NULL;
	GtkScrolledWindow* scroll = NULL;
	GtkScrolledWindow* _tmp10_ = NULL;
	GtkBox* _tmp11_ = NULL;
	GtkTextBuffer* _tmp12_ = NULL;
	GtkTextBuffer* _tmp13_ = NULL;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data39_ = g_slice_new0 (Block39Data);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data39_->_ref_count_ = 1;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data39_->self = g_object_ref (self);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = boxes_libvirt_machine_properties_collect_logs (self);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data39_->log = _tmp0_;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _ ("Troubleshooting log");
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = self->priv->machine;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = boxes_machine_get_window ((BoxesMachine*) _tmp2_);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _tmp3_;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = _ ("_Save");
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = _ ("Copy to clipboard");
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = _ ("_Close");
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = (GtkDialog*) gtk_dialog_new_with_buttons (_tmp1_, (GtkWindow*) _tmp4_, GTK_DIALOG_DESTROY_WITH_PARENT, _tmp5_, 100, _tmp6_, 101, _tmp7_, GTK_RESPONSE_OK, NULL);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp8_);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data39_->dialog = _tmp8_;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_window_set_default_size ((GtkWindow*) _data39_->dialog, 640, 480);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = (GtkTextView*) gtk_text_view_new ();
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp9_);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	text = _tmp9_;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_text_view_set_editable (text, FALSE);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp10_);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	scroll = _tmp10_;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) scroll, (GtkWidget*) text);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_vexpand ((GtkWidget*) scroll, TRUE);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = (GtkBox*) gtk_dialog_get_content_area (_data39_->dialog);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp11_, (GtkWidget*) scroll);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp12_ = gtk_text_view_get_buffer (text);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = _tmp12_;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_text_buffer_set_text (_tmp13_, _data39_->log, -1);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_show_all ((GtkWidget*) _data39_->dialog);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_data (_data39_->dialog, "response", (GCallback) ___lambda129__gtk_dialog_response, block39_data_ref (_data39_), (GClosureNotify) block39_data_unref, 0);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (scroll);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (text);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block39_data_unref (_data39_);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data39_ = NULL;
#line 2167 "libvirt-machine-properties.c"
}


static void ____lambda128__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda128_ ((BoxesLibvirtMachineProperties*) self);
#line 2174 "libvirt-machine-properties.c"
}


static Block42Data* block42_data_ref (Block42Data* _data42_) {
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data42_->_ref_count_);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data42_;
#line 2183 "libvirt-machine-properties.c"
}


static void block42_data_unref (void * _userdata_) {
	Block42Data* _data42_;
	_data42_ = (Block42Data*) _userdata_;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data42_->_ref_count_)) {
#line 2192 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data42_->self;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data42_->property);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block42Data, _data42_);
#line 2202 "libvirt-machine-properties.c"
	}
}


static void ____lambda134_ (Block42Data* _data42_) {
	BoxesLibvirtMachineProperties* self;
	GError * _inner_error_ = NULL;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data42_->self;
#line 2212 "libvirt-machine-properties.c"
	{
		BoxesLibvirtMachine* _tmp0_ = NULL;
		BoxesProperty* _tmp1_ = NULL;
		BoxesProperty* _tmp2_ = NULL;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_try_enable_usb_redir (self, &_inner_error_);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2221 "libvirt-machine-properties.c"
			goto __catch34_g_error;
		}
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_update_domain_config (_tmp0_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _data42_->property;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_emit_by_name (_tmp1_, "refresh-properties");
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _data42_->property;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_reboot_required (_tmp2_, TRUE);
#line 2236 "libvirt-machine-properties.c"
	}
	goto __finally34;
	__catch34_g_error:
	{
		GError* _error_ = NULL;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:254: Failed to enable usb");
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 2250 "libvirt-machine-properties.c"
	}
	__finally34:
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 2261 "libvirt-machine-properties.c"
	}
}


static void _____lambda134__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	____lambda134_ (self);
#line 2269 "libvirt-machine-properties.c"
}


static Block43Data* block43_data_ref (Block43Data* _data43_) {
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data43_->_ref_count_);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data43_;
#line 2278 "libvirt-machine-properties.c"
}


static void block43_data_unref (void * _userdata_) {
	Block43Data* _data43_;
	_data43_ = (Block43Data*) _userdata_;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data43_->_ref_count_)) {
#line 2287 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data43_->self;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data43_->property);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block43Data, _data43_);
#line 2297 "libvirt-machine-properties.c"
	}
}


static void ____lambda135_ (Block43Data* _data43_) {
	BoxesLibvirtMachineProperties* self;
	GError * _inner_error_ = NULL;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data43_->self;
#line 2307 "libvirt-machine-properties.c"
	{
		BoxesLibvirtMachine* _tmp0_ = NULL;
		BoxesProperty* _tmp1_ = NULL;
		BoxesProperty* _tmp2_ = NULL;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_try_enable_smartcard (self, &_inner_error_);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2316 "libvirt-machine-properties.c"
			goto __catch35_g_error;
		}
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_update_domain_config (_tmp0_);
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _data43_->property;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_emit_by_name (_tmp1_, "refresh-properties");
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _data43_->property;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_reboot_required (_tmp2_, TRUE);
#line 2331 "libvirt-machine-properties.c"
	}
	goto __finally35;
	__catch35_g_error:
	{
		GError* _error_ = NULL;
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:272: Failed to enable smartcard");
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 2345 "libvirt-machine-properties.c"
	}
	__finally35:
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 2356 "libvirt-machine-properties.c"
	}
}


static void _____lambda135__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	____lambda135_ (self);
#line 2364 "libvirt-machine-properties.c"
}


static GList* boxes_libvirt_machine_properties_real_get_properties (BoxesIPropertiesProvider* base, BoxesPropertiesPage page, PropertyCreationFlag* flags) {
	BoxesLibvirtMachineProperties * self;
	GList* result = NULL;
	GList* list = NULL;
	gboolean _tmp0_ = FALSE;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	BoxesPropertiesPage _tmp9_ = 0;
	GError * _inner_error_ = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = (BoxesLibvirtMachineProperties*) base;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	list = NULL;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_machine_is_on ((BoxesMachine*) _tmp1_);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp2_) {
#line 2387 "libvirt-machine-properties.c"
		BoxesLibvirtMachine* _tmp3_ = NULL;
		BoxesDisplay* _tmp4_ = NULL;
		BoxesDisplay* _tmp5_ = NULL;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = self->priv->machine;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = boxes_machine_get_display ((BoxesMachine*) _tmp3_);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _tmp4_;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _tmp5_ == NULL;
#line 2399 "libvirt-machine-properties.c"
	} else {
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = FALSE;
#line 2403 "libvirt-machine-properties.c"
	}
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_) {
#line 2407 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp6_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6_ = self->priv->machine;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_update_display (_tmp6_, &_inner_error_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2416 "libvirt-machine-properties.c"
				goto __catch31_g_error;
			}
		}
		goto __finally31;
		__catch31_g_error:
		{
			GError* e = NULL;
			GError* _tmp7_ = NULL;
			const gchar* _tmp8_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			e = _inner_error_;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_inner_error_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp7_ = e;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp8_ = _tmp7_->message;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_warning ("libvirt-machine-properties.vala:116: %s", _tmp8_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_error_free0 (e);
#line 2438 "libvirt-machine-properties.c"
		}
		__finally31:
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__g_list_free__g_object_unref0_0 (list);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_inner_error_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return NULL;
#line 2451 "libvirt-machine-properties.c"
		}
	}
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = page;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_tmp9_) {
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_LOGIN:
#line 2460 "libvirt-machine-properties.c"
		{
			Block38Data* _data38_;
			BoxesStringProperty* property = NULL;
			const gchar* _tmp10_ = NULL;
			BoxesLibvirtMachine* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			BoxesStringProperty* _tmp14_ = NULL;
			BoxesStringProperty* _tmp15_ = NULL;
			BoxesStringProperty* _tmp16_ = NULL;
			BoxesStringProperty* _tmp17_ = NULL;
			BoxesStringProperty* _tmp18_ = NULL;
			BoxesLibvirtMachine* _tmp19_ = NULL;
			const gchar* _tmp20_ = NULL;
			BoxesLibvirtMachine* _tmp21_ = NULL;
			BoxesCollectionSource* _tmp22_ = NULL;
			gchar* _tmp23_ = NULL;
			gchar* _tmp24_ = NULL;
			gchar* _tmp25_ = NULL;
			BoxesStringProperty* _tmp26_ = NULL;
			BoxesStringProperty* _tmp27_ = NULL;
			BoxesLibvirtMachine* _tmp28_ = NULL;
			BoxesDisplay* _tmp29_ = NULL;
			BoxesDisplay* _tmp30_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data38_ = g_slice_new0 (Block38Data);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data38_->_ref_count_ = 1;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data38_->self = g_object_ref (self);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = _ ("Name");
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = self->priv->machine;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp12_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp11_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp13_ = _tmp12_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp14_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp10_, _tmp13_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			property = _tmp14_;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp15_ = property;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_string_property_set_editable (_tmp15_, TRUE);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = property;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp16_, "changed", (GCallback) ____lambda122__boxes_string_property_changed, self, 0);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = property;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = _g_object_ref0 (_tmp17_);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data38_->name_property = _tmp18_;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp19_ = self->priv->machine;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_data ((GObject*) _tmp19_, "notify::name", (GCallback) ____lambda123__g_object_notify, block38_data_ref (_data38_), (GClosureNotify) block38_data_unref, 0);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp20_ = _ ("Virtualizer");
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp21_ = self->priv->machine;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp22_ = ((BoxesMachine*) _tmp21_)->source;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp23_ = boxes_collection_source_get_uri (_tmp22_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = _tmp23_;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = _tmp24_;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp20_, _tmp25_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = _tmp26_;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp27_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp25_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp28_ = self->priv->machine;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp29_ = boxes_machine_get_display ((BoxesMachine*) _tmp28_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp30_ = _tmp29_;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp30_ != NULL) {
#line 2549 "libvirt-machine-properties.c"
				const gchar* _tmp31_ = NULL;
				BoxesLibvirtMachine* _tmp32_ = NULL;
				BoxesDisplay* _tmp33_ = NULL;
				BoxesDisplay* _tmp34_ = NULL;
				gchar* _tmp35_ = NULL;
				gchar* _tmp36_ = NULL;
				gchar* _tmp37_ = NULL;
				BoxesStringProperty* _tmp38_ = NULL;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp31_ = _ ("URI");
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp32_ = self->priv->machine;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp33_ = boxes_machine_get_display ((BoxesMachine*) _tmp32_);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp34_ = _tmp33_;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp35_ = boxes_display_get_uri (_tmp34_);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp36_ = _tmp35_;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp37_ = _tmp36_;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp38_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp31_, _tmp37_);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (property);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				property = _tmp38_;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_free0 (_tmp37_);
#line 2580 "libvirt-machine-properties.c"
			}
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (property);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			block38_data_unref (_data38_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data38_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2590 "libvirt-machine-properties.c"
		}
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_SYSTEM:
#line 2594 "libvirt-machine-properties.c"
		{
			BoxesSizeProperty* ram_property = NULL;
			BoxesSizeProperty* _tmp39_ = NULL;
			BoxesSizeProperty* storage_property = NULL;
			BoxesSizeProperty* _tmp40_ = NULL;
			BoxesSizeProperty* _tmp41_ = NULL;
			BoxesSizeProperty* _tmp42_ = NULL;
			GtkButton* button = NULL;
			const gchar* _tmp43_ = NULL;
			GtkButton* _tmp44_ = NULL;
			GtkButton* _tmp45_ = NULL;
			GtkButton* _tmp46_ = NULL;
			BoxesProperty* _tmp47_ = NULL;
			BoxesProperty* _tmp48_ = NULL;
			GtkButton* _tmp49_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp39_ = boxes_libvirt_machine_properties_add_ram_property (self, &list);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			ram_property = _tmp39_;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp40_ = boxes_libvirt_machine_properties_add_storage_property (self, &list);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			storage_property = _tmp40_;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp41_ = ram_property;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp42_ = storage_property;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_properties_mark_recommended_resources (self, _tmp41_, _tmp42_, NULL, NULL);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp43_ = _ ("Troubleshooting log");
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp44_ = (GtkButton*) gtk_button_new_with_label (_tmp43_);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_ref_sink (_tmp44_);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			button = _tmp44_;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp45_ = button;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_widget_set_halign ((GtkWidget*) _tmp45_, GTK_ALIGN_START);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp46_ = button;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp47_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, NULL, (GtkWidget*) _tmp46_, NULL);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp48_ = _tmp47_;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp48_);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp49_ = button;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp49_, "clicked", (GCallback) ____lambda128__gtk_button_clicked, self, 0);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (button);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (storage_property);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (ram_property);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2656 "libvirt-machine-properties.c"
		}
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_DISPLAY:
#line 2660 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp50_ = NULL;
			BoxesDisplay* _tmp51_ = NULL;
			BoxesDisplay* _tmp52_ = NULL;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp50_ = self->priv->machine;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp51_ = boxes_machine_get_display ((BoxesMachine*) _tmp50_);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp52_ = _tmp51_;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp52_ != NULL) {
#line 2673 "libvirt-machine-properties.c"
				const gchar* _tmp53_ = NULL;
				BoxesLibvirtMachine* _tmp54_ = NULL;
				BoxesDisplay* _tmp55_ = NULL;
				BoxesDisplay* _tmp56_ = NULL;
				const gchar* _tmp57_ = NULL;
				const gchar* _tmp58_ = NULL;
				BoxesStringProperty* _tmp59_ = NULL;
				BoxesStringProperty* _tmp60_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp53_ = _ ("Protocol");
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp54_ = self->priv->machine;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp55_ = boxes_machine_get_display ((BoxesMachine*) _tmp54_);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp56_ = _tmp55_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp57_ = boxes_display_get_protocol (_tmp56_);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp58_ = _tmp57_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp59_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp53_, _tmp58_);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp60_ = _tmp59_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (_tmp60_);
#line 2700 "libvirt-machine-properties.c"
			}
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2704 "libvirt-machine-properties.c"
		}
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_DEVICES:
#line 2708 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp61_ = NULL;
			GVirConfigDomain* _tmp62_ = NULL;
			GVirConfigDomain* _tmp63_ = NULL;
			GList* _tmp64_ = NULL;
			gboolean has_usb_redir = FALSE;
			gboolean has_smartcard = FALSE;
			gboolean _tmp88_ = FALSE;
			gboolean _tmp90_ = FALSE;
			gboolean _tmp91_ = FALSE;
			gboolean _tmp99_ = FALSE;
			gboolean _tmp100_ = FALSE;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp61_ = self->priv->machine;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp62_ = boxes_libvirt_machine_get_domain_config (_tmp61_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp63_ = _tmp62_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp64_ = gvir_config_domain_get_devices (_tmp63_);
#line 2729 "libvirt-machine-properties.c"
			{
				GList* device_config_collection = NULL;
				GList* device_config_it = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				device_config_collection = _tmp64_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				for (device_config_it = device_config_collection; device_config_it != NULL; device_config_it = device_config_it->next) {
#line 2737 "libvirt-machine-properties.c"
					GVirConfigDomainDevice* _tmp65_ = NULL;
					GVirConfigDomainDevice* device_config = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp65_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_config_it->data);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					device_config = _tmp65_;
#line 2744 "libvirt-machine-properties.c"
					{
						GVirConfigDomainDevice* _tmp66_ = NULL;
						GVirConfigDomainDisk* disk_config = NULL;
						GVirConfigDomainDevice* _tmp67_ = NULL;
						GVirConfigDomainDisk* _tmp68_ = NULL;
						GVirConfigDomainDiskGuestDeviceType disk_type = 0;
						GVirConfigDomainDisk* _tmp69_ = NULL;
						GVirConfigDomainDiskGuestDeviceType _tmp70_ = 0;
						GVirConfigDomainDiskGuestDeviceType _tmp71_ = 0;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp66_ = device_config;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp66_, gvir_config_domain_disk_get_type ())) {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_g_object_unref0 (device_config);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							continue;
#line 2762 "libvirt-machine-properties.c"
						}
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp67_ = device_config;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp68_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp67_, gvir_config_domain_disk_get_type ()) ? ((GVirConfigDomainDisk*) _tmp67_) : NULL);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						disk_config = _tmp68_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp69_ = disk_config;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp70_ = gvir_config_domain_disk_get_guest_device_type (_tmp69_);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						disk_type = _tmp70_;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp71_ = disk_type;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						if (_tmp71_ == GVIR_CONFIG_DOMAIN_DISK_GUEST_DEVICE_CDROM) {
#line 2780 "libvirt-machine-properties.c"
							GVirConfigDomainDisk* _tmp72_ = NULL;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_tmp72_ = disk_config;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							boxes_libvirt_machine_properties_add_cdrom_property (self, _tmp72_, &list);
#line 2786 "libvirt-machine-properties.c"
						}
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_g_object_unref0 (disk_config);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_g_object_unref0 (device_config);
#line 2792 "libvirt-machine-properties.c"
					}
				}
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				__g_list_free__g_object_unref0_0 (device_config_collection);
#line 2797 "libvirt-machine-properties.c"
			}
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			has_usb_redir = FALSE;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			has_smartcard = FALSE;
#line 2803 "libvirt-machine-properties.c"
			{
				GVirConfigDomain* inactive_config = NULL;
				BoxesLibvirtMachine* _tmp73_ = NULL;
				GVirDomain* _tmp74_ = NULL;
				GVirDomain* _tmp75_ = NULL;
				GVirConfigDomain* _tmp76_ = NULL;
				GVirConfigDomain* _tmp77_ = NULL;
				GList* _tmp78_ = NULL;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp73_ = self->priv->machine;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp74_ = boxes_libvirt_machine_get_domain (_tmp73_);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp75_ = _tmp74_;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp76_ = gvir_domain_get_config (_tmp75_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				inactive_config = _tmp76_;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2824 "libvirt-machine-properties.c"
					goto __catch33_g_error;
				}
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp77_ = inactive_config;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp78_ = gvir_config_domain_get_devices (_tmp77_);
#line 2831 "libvirt-machine-properties.c"
				{
					GList* device_collection = NULL;
					GList* device_it = NULL;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					device_collection = _tmp78_;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					for (device_it = device_collection; device_it != NULL; device_it = device_it->next) {
#line 2839 "libvirt-machine-properties.c"
						GVirConfigDomainDevice* _tmp79_ = NULL;
						GVirConfigDomainDevice* device = NULL;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp79_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_it->data);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						device = _tmp79_;
#line 2846 "libvirt-machine-properties.c"
						{
							GVirConfigDomainDevice* _tmp80_ = NULL;
							GVirConfigDomainDevice* _tmp81_ = NULL;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_tmp80_ = device;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp80_, gvir_config_domain_redirdev_get_type ())) {
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
								has_usb_redir = TRUE;
#line 2856 "libvirt-machine-properties.c"
							}
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_tmp81_ = device;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp81_, gvir_config_domain_smartcard_get_type ())) {
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
								has_smartcard = TRUE;
#line 2864 "libvirt-machine-properties.c"
							}
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_g_object_unref0 (device);
#line 2868 "libvirt-machine-properties.c"
						}
					}
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					__g_list_free__g_object_unref0_0 (device_collection);
#line 2873 "libvirt-machine-properties.c"
				}
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (inactive_config);
#line 2877 "libvirt-machine-properties.c"
			}
			goto __finally33;
			__catch33_g_error:
			{
				GError* _error_ = NULL;
				BoxesLibvirtMachine* _tmp82_ = NULL;
				GVirDomain* _tmp83_ = NULL;
				GVirDomain* _tmp84_ = NULL;
				const gchar* _tmp85_ = NULL;
				GError* _tmp86_ = NULL;
				const gchar* _tmp87_ = NULL;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_error_ = _inner_error_;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_inner_error_ = NULL;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp82_ = self->priv->machine;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp83_ = boxes_libvirt_machine_get_domain (_tmp82_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp84_ = _tmp83_;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp85_ = gvir_domain_get_name (_tmp84_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp86_ = _error_;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp87_ = _tmp86_->message;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_warning ("libvirt-machine-properties.vala:233: Failed to fetch configuration for" \
" domain '%s': %s", _tmp85_, _tmp87_);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_error_free0 (_error_);
#line 2909 "libvirt-machine-properties.c"
			}
			__finally33:
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				__g_list_free__g_object_unref0_0 (list);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_clear_error (&_inner_error_);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				return NULL;
#line 2922 "libvirt-machine-properties.c"
			}
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp88_ = has_usb_redir;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (!_tmp88_) {
#line 2928 "libvirt-machine-properties.c"
				PropertyCreationFlag _tmp89_ = 0;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp89_ = *flags;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				*flags = _tmp89_ | PROPERTY_CREATION_FLAG_NO_USB;
#line 2934 "libvirt-machine-properties.c"
			}
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp91_ = has_usb_redir;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (!_tmp91_) {
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp90_ = HAVE_USBREDIR;
#line 2942 "libvirt-machine-properties.c"
			} else {
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp90_ = FALSE;
#line 2946 "libvirt-machine-properties.c"
			}
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp90_) {
#line 2950 "libvirt-machine-properties.c"
				Block42Data* _data42_;
				GtkButton* button = NULL;
				const gchar* _tmp92_ = NULL;
				GtkButton* _tmp93_ = NULL;
				GtkButton* _tmp94_ = NULL;
				const gchar* _tmp95_ = NULL;
				GtkButton* _tmp96_ = NULL;
				BoxesProperty* _tmp97_ = NULL;
				GtkButton* _tmp98_ = NULL;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data42_ = g_slice_new0 (Block42Data);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data42_->_ref_count_ = 1;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data42_->self = g_object_ref (self);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp92_ = _ ("Add support to guest");
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp93_ = (GtkButton*) gtk_button_new_with_label (_tmp92_);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_object_ref_sink (_tmp93_);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				button = _tmp93_;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp94_ = button;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				gtk_widget_set_halign ((GtkWidget*) _tmp94_, GTK_ALIGN_START);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp95_ = _ ("USB device support");
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp96_ = button;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp97_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp95_, (GtkWidget*) _tmp96_, NULL);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data42_->property = _tmp97_;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp98_ = button;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_signal_connect_data (_tmp98_, "clicked", (GCallback) _____lambda134__gtk_button_clicked, block42_data_ref (_data42_), (GClosureNotify) block42_data_unref, 0);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (button);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				block42_data_unref (_data42_);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data42_ = NULL;
#line 2996 "libvirt-machine-properties.c"
			}
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp100_ = has_smartcard;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (!_tmp100_) {
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp99_ = HAVE_SMARTCARD;
#line 3004 "libvirt-machine-properties.c"
			} else {
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp99_ = FALSE;
#line 3008 "libvirt-machine-properties.c"
			}
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp99_) {
#line 3012 "libvirt-machine-properties.c"
				Block43Data* _data43_;
				GtkButton* button = NULL;
				const gchar* _tmp101_ = NULL;
				GtkButton* _tmp102_ = NULL;
				GtkButton* _tmp103_ = NULL;
				const gchar* _tmp104_ = NULL;
				GtkButton* _tmp105_ = NULL;
				BoxesProperty* _tmp106_ = NULL;
				GtkButton* _tmp107_ = NULL;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data43_ = g_slice_new0 (Block43Data);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data43_->_ref_count_ = 1;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data43_->self = g_object_ref (self);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp101_ = _ ("Add support to guest");
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp102_ = (GtkButton*) gtk_button_new_with_label (_tmp101_);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_object_ref_sink (_tmp102_);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				button = _tmp102_;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp103_ = button;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				gtk_widget_set_halign ((GtkWidget*) _tmp103_, GTK_ALIGN_START);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp104_ = _ ("Smartcard support");
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp105_ = button;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp106_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp104_, (GtkWidget*) _tmp105_, NULL);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data43_->property = _tmp106_;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp107_ = button;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_signal_connect_data (_tmp107_, "clicked", (GCallback) _____lambda135__gtk_button_clicked, block43_data_ref (_data43_), (GClosureNotify) block43_data_unref, 0);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (button);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				block43_data_unref (_data43_);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data43_ = NULL;
#line 3058 "libvirt-machine-properties.c"
			}
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 3062 "libvirt-machine-properties.c"
		}
		default:
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		break;
#line 3067 "libvirt-machine-properties.c"
	}
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = list;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 3073 "libvirt-machine-properties.c"
}


static Block44Data* block44_data_ref (Block44Data* _data44_) {
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data44_->_ref_count_);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data44_;
#line 3082 "libvirt-machine-properties.c"
}


static void block44_data_unref (void * _userdata_) {
	Block44Data* _data44_;
	_data44_ = (Block44Data*) _userdata_;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data44_->_ref_count_)) {
#line 3091 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data44_->self;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data44_->button_label);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data44_->label);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data44_->disk_config);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block44Data, _data44_);
#line 3105 "libvirt-machine-properties.c"
	}
}


static Block45Data* block45_data_ref (Block45Data* _data45_) {
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data45_->_ref_count_);
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data45_;
#line 3115 "libvirt-machine-properties.c"
}


static void block45_data_unref (void * _userdata_) {
	Block45Data* _data45_;
	_data45_ = (Block45Data*) _userdata_;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data45_->_ref_count_)) {
#line 3124 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data45_->_data44_->self;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data45_->dialog);
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block44_data_unref (_data45_->_data44_);
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data45_->_data44_ = NULL;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block45Data, _data45_);
#line 3136 "libvirt-machine-properties.c"
	}
}


static void ___lambda133_ (Block45Data* _data45_, gint response) {
	Block44Data* _data44_;
	BoxesLibvirtMachineProperties* self;
	gint _tmp0_ = 0;
	GtkFileChooserDialog* _tmp33_ = NULL;
	GError * _inner_error_ = NULL;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_ = _data45_->_data44_;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data44_->self;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = response;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_ == ((gint) GTK_RESPONSE_ACCEPT)) {
#line 3155 "libvirt-machine-properties.c"
		gchar* path = NULL;
		GtkFileChooserDialog* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		GVirConfigDomainDisk* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _data45_->dialog;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = gtk_file_chooser_get_filename ((GtkFileChooser*) _tmp1_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		path = _tmp2_;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _data44_->disk_config;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = path;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_disk_set_source (_tmp3_, _tmp4_);
#line 3173 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp5_ = NULL;
			GVirDomain* _tmp6_ = NULL;
			GVirDomain* _tmp7_ = NULL;
			GVirConfigDomainDisk* _tmp8_ = NULL;
			GtkLabel* _tmp9_ = NULL;
			const gchar* _tmp10_ = NULL;
			GtkLabel* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			gchar* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp5_ = self->priv->machine;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6_ = boxes_libvirt_machine_get_domain (_tmp5_);
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp7_ = _tmp6_;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp8_ = _data44_->disk_config;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gvir_domain_update_device (_tmp7_, (GVirConfigDomainDevice*) _tmp8_, (guint) GVIR_DOMAIN_UPDATE_DEVICE_CURRENT, &_inner_error_);
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3197 "libvirt-machine-properties.c"
				goto __catch36_g_error;
			}
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp9_ = _data44_->button_label;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = _ ("Remove");
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_text (_tmp9_, _tmp10_);
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = _data44_->label;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp12_ = path;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp13_ = boxes_get_utf8_basename (_tmp12_);
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp14_ = _tmp13_;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_text (_tmp11_, _tmp14_);
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp14_);
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data44_->empty = FALSE;
#line 3220 "libvirt-machine-properties.c"
		}
		goto __finally36;
		__catch36_g_error:
		{
			GError* e = NULL;
			gchar* path_basename = NULL;
			const gchar* _tmp15_ = NULL;
			gchar* _tmp16_ = NULL;
			gchar* msg = NULL;
			const gchar* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
			BoxesLibvirtMachine* _tmp19_ = NULL;
			const gchar* _tmp20_ = NULL;
			const gchar* _tmp21_ = NULL;
			BoxesLibvirtMachine* _tmp22_ = NULL;
			const gchar* _tmp23_ = NULL;
			const gchar* _tmp24_ = NULL;
			gchar* _tmp25_ = NULL;
			gchar* _tmp26_ = NULL;
			const gchar* _tmp27_ = NULL;
			BoxesLibvirtMachine* _tmp28_ = NULL;
			const gchar* _tmp29_ = NULL;
			const gchar* _tmp30_ = NULL;
			GError* _tmp31_ = NULL;
			const gchar* _tmp32_ = NULL;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			e = _inner_error_;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_inner_error_ = NULL;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp15_ = path;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = boxes_get_utf8_basename (_tmp15_);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			path_basename = _tmp16_;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = _ ("Insertion of '%s' as a CD/DVD into '%s' failed");
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = g_strdup (_tmp17_);
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			msg = _tmp18_;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp19_ = self->priv->machine;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp20_ = msg;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp21_ = path_basename;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp22_ = self->priv->machine;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp23_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp22_);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = _tmp23_;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = g_strdup_printf (_tmp20_, _tmp21_, _tmp24_);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = _tmp25_;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_emit_by_name ((BoxesMachine*) _tmp19_, "got-error", _tmp26_);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp26_);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = path_basename;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp28_ = self->priv->machine;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp29_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp28_);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp30_ = _tmp29_;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp31_ = e;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = _tmp31_->message;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_debug ("libvirt-machine-properties.vala:353: Error inserting '%s' as CD into '" \
"%s': %s", _tmp27_, _tmp30_, _tmp32_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (msg);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (path_basename);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_error_free0 (e);
#line 3302 "libvirt-machine-properties.c"
		}
		__finally36:
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (path);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_inner_error_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 3315 "libvirt-machine-properties.c"
		}
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (path);
#line 3319 "libvirt-machine-properties.c"
	}
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp33_ = _data45_->dialog;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_destroy ((GtkWidget*) _tmp33_);
#line 3325 "libvirt-machine-properties.c"
}


static void ____lambda133__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda133_ (self, response_id);
#line 3332 "libvirt-machine-properties.c"
}


static void __lambda132_ (Block44Data* _data44_) {
	BoxesLibvirtMachineProperties* self;
	gboolean _tmp0_ = FALSE;
	GError * _inner_error_ = NULL;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data44_->self;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data44_->empty;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_) {
#line 3346 "libvirt-machine-properties.c"
		Block45Data* _data45_;
		const gchar* _tmp1_ = NULL;
		BoxesLibvirtMachine* _tmp2_ = NULL;
		BoxesAppWindow* _tmp3_ = NULL;
		BoxesAppWindow* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		GtkFileChooserDialog* _tmp7_ = NULL;
		GtkFileChooserDialog* _tmp8_ = NULL;
		GtkFileChooserDialog* _tmp9_ = NULL;
		GtkFileChooserDialog* _tmp10_ = NULL;
		GtkFileChooserDialog* _tmp11_ = NULL;
		GtkFileFilter* _tmp12_ = NULL;
		GtkFileFilter* _tmp13_ = NULL;
		GtkFileChooserDialog* _tmp14_ = NULL;
		GtkFileFilter* _tmp15_ = NULL;
		GtkFileFilter* _tmp16_ = NULL;
		GtkFileChooserDialog* _tmp17_ = NULL;
		GtkFileChooserDialog* _tmp18_ = NULL;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data45_ = g_slice_new0 (Block45Data);
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data45_->_ref_count_ = 1;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data45_->_data44_ = block44_data_ref (_data44_);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _ ("Select a device or ISO file");
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = self->priv->machine;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = boxes_machine_get_window ((BoxesMachine*) _tmp2_);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = _tmp3_;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _ ("_Cancel");
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _ ("_Open");
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (_tmp1_, (GtkWindow*) _tmp4_, GTK_FILE_CHOOSER_ACTION_OPEN, _tmp5_, GTK_RESPONSE_CANCEL, _tmp6_, GTK_RESPONSE_ACCEPT, NULL);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_ref_sink (_tmp7_);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data45_->dialog = _tmp7_;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _data45_->dialog;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_window_set_modal ((GtkWindow*) _tmp8_, TRUE);
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = _data45_->dialog;
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_chooser_set_show_hidden ((GtkFileChooser*) _tmp9_, FALSE);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _data45_->dialog;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_chooser_set_local_only ((GtkFileChooser*) _tmp10_, TRUE);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = _data45_->dialog;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = gtk_file_filter_new ();
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_ref_sink (_tmp12_);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = _tmp12_;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_chooser_set_filter ((GtkFileChooser*) _tmp11_, _tmp13_);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_tmp13_);
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _data45_->dialog;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = gtk_file_chooser_get_filter ((GtkFileChooser*) _tmp14_);
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = _tmp15_;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_filter_add_mime_type (_tmp16_, "application/x-cd-image");
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _data45_->dialog;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_connect_data ((GtkDialog*) _tmp17_, "response", (GCallback) ____lambda133__gtk_dialog_response, block45_data_ref (_data45_), (GClosureNotify) block45_data_unref, 0);
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = _data45_->dialog;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_widget_show_all ((GtkWidget*) _tmp18_);
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block45_data_unref (_data45_);
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data45_ = NULL;
#line 3434 "libvirt-machine-properties.c"
	} else {
		GVirConfigDomainDisk* _tmp19_ = NULL;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _data44_->disk_config;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_disk_set_source (_tmp19_, "");
#line 3441 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp20_ = NULL;
			GVirDomain* _tmp21_ = NULL;
			GVirDomain* _tmp22_ = NULL;
			GVirConfigDomainDisk* _tmp23_ = NULL;
			GtkLabel* _tmp24_ = NULL;
			const gchar* _tmp25_ = NULL;
			GtkLabel* _tmp26_ = NULL;
			const gchar* _tmp27_ = NULL;
			gchar* _tmp28_ = NULL;
			gchar* _tmp29_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp20_ = self->priv->machine;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp21_ = boxes_libvirt_machine_get_domain (_tmp20_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp22_ = _tmp21_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp23_ = _data44_->disk_config;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gvir_domain_update_device (_tmp22_, (GVirConfigDomainDevice*) _tmp23_, (guint) GVIR_DOMAIN_UPDATE_DEVICE_CURRENT, &_inner_error_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3465 "libvirt-machine-properties.c"
				goto __catch37_g_error;
			}
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data44_->empty = TRUE;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = _data44_->button_label;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = _ ("Select");
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_text (_tmp24_, _tmp25_);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = _data44_->label;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = _ ("empty");
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp28_ = g_markup_printf_escaped ("<i>%s</i>", _tmp27_);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp29_ = _tmp28_;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_markup (_tmp26_, _tmp29_);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp29_);
#line 3488 "libvirt-machine-properties.c"
		}
		goto __finally37;
		__catch37_g_error:
		{
			GError* e = NULL;
			BoxesLibvirtMachine* _tmp30_ = NULL;
			const gchar* _tmp31_ = NULL;
			BoxesLibvirtMachine* _tmp32_ = NULL;
			const gchar* _tmp33_ = NULL;
			const gchar* _tmp34_ = NULL;
			gchar* _tmp35_ = NULL;
			gchar* _tmp36_ = NULL;
			BoxesLibvirtMachine* _tmp37_ = NULL;
			const gchar* _tmp38_ = NULL;
			const gchar* _tmp39_ = NULL;
			GError* _tmp40_ = NULL;
			const gchar* _tmp41_ = NULL;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			e = _inner_error_;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_inner_error_ = NULL;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp30_ = self->priv->machine;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp31_ = _ ("Removal of CD/DVD from '%s' failed");
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = self->priv->machine;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp32_);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp34_ = _tmp33_;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp35_ = g_strdup_printf (_tmp31_, _tmp34_);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp36_ = _tmp35_;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_emit_by_name ((BoxesMachine*) _tmp30_, "got-error", _tmp36_);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp36_);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp37_ = self->priv->machine;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp38_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp37_);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp39_ = _tmp38_;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp40_ = e;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp41_ = _tmp40_->message;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_debug ("libvirt-machine-properties.vala:369: Error ejecting CD from '%s': %s", _tmp39_, _tmp41_);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_error_free0 (e);
#line 3542 "libvirt-machine-properties.c"
		}
		__finally37:
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_inner_error_);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 3553 "libvirt-machine-properties.c"
		}
	}
}


static void ___lambda132__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda132_ (self);
#line 3562 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_add_cdrom_property (BoxesLibvirtMachineProperties* self, GVirConfigDomainDisk* disk_config, GList** list) {
	Block44Data* _data44_;
	GVirConfigDomainDisk* _tmp0_ = NULL;
	GVirConfigDomainDisk* _tmp1_ = NULL;
	GtkGrid* grid = NULL;
	GtkGrid* _tmp2_ = NULL;
	GtkGrid* _tmp3_ = NULL;
	GtkGrid* _tmp4_ = NULL;
	GtkLabel* _tmp5_ = NULL;
	GtkLabel* _tmp6_ = NULL;
	GtkGrid* _tmp7_ = NULL;
	GtkLabel* _tmp8_ = NULL;
	gchar* source = NULL;
	GVirConfigDomainDisk* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	const gchar* _tmp13_ = NULL;
	gboolean _tmp15_ = FALSE;
	BoxesLibvirtMachine* _tmp24_ = NULL;
	BoxesVMCreator* _tmp25_ = NULL;
	BoxesVMCreator* _tmp26_ = NULL;
	GtkLabel* _tmp51_ = NULL;
	GtkButton* button = NULL;
	GtkButton* _tmp52_ = NULL;
	GtkButton* _tmp53_ = NULL;
	GtkLabel* _tmp54_ = NULL;
	GtkGrid* _tmp55_ = NULL;
	GtkButton* _tmp56_ = NULL;
	gboolean _tmp57_ = FALSE;
	GtkButton* _tmp62_ = NULL;
	const gchar* _tmp63_ = NULL;
	GtkGrid* _tmp64_ = NULL;
	BoxesProperty* _tmp65_ = NULL;
	BoxesProperty* _tmp66_ = NULL;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (disk_config != NULL);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_ = g_slice_new0 (Block44Data);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_->_ref_count_ = 1;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_->self = g_object_ref (self);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = disk_config;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data44_->disk_config);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_->disk_config = _tmp1_;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = (GtkGrid*) gtk_grid_new ();
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp2_);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	grid = _tmp2_;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = grid;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_orientable_set_orientation ((GtkOrientable*) _tmp3_, GTK_ORIENTATION_HORIZONTAL);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = grid;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_set_column_spacing (_tmp4_, (guint) 12);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = (GtkLabel*) gtk_label_new ("");
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp5_);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_->label = _tmp5_;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = _data44_->label;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_label_set_ellipsize (_tmp6_, PANGO_ELLIPSIZE_END);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = grid;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = _data44_->label;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp7_, (GtkWidget*) _tmp8_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = _data44_->disk_config;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = gvir_config_domain_disk_get_source (_tmp9_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = g_strdup (_tmp10_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	source = _tmp11_;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = source;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp13_ == NULL) {
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = TRUE;
#line 3663 "libvirt-machine-properties.c"
	} else {
		const gchar* _tmp14_ = NULL;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = source;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = g_strcmp0 (_tmp14_, "") == 0;
#line 3670 "libvirt-machine-properties.c"
	}
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_->empty = _tmp12_;
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp15_ = _data44_->empty;
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp15_) {
#line 3678 "libvirt-machine-properties.c"
		GtkLabel* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = _data44_->label;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _ ("empty");
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = g_markup_printf_escaped ("<i>%s</i>", _tmp17_);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_markup (_tmp16_, _tmp19_);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp19_);
#line 3695 "libvirt-machine-properties.c"
	} else {
		GtkLabel* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = _data44_->label;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = source;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = boxes_get_utf8_basename (_tmp21_);
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = _tmp22_;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text (_tmp20_, _tmp23_);
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp23_);
#line 3713 "libvirt-machine-properties.c"
	}
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp24_ = self->priv->machine;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp25_ = boxes_libvirt_machine_get_vm_creator (_tmp24_);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp26_ = _tmp25_;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp26_ != NULL) {
#line 3723 "libvirt-machine-properties.c"
		BoxesInstallerMedia* media = NULL;
		BoxesLibvirtMachine* _tmp27_ = NULL;
		BoxesVMCreator* _tmp28_ = NULL;
		BoxesVMCreator* _tmp29_ = NULL;
		BoxesInstallerMedia* _tmp30_ = NULL;
		BoxesInstallerMedia* _tmp31_ = NULL;
		BoxesInstallerMedia* _tmp32_ = NULL;
		gboolean _tmp33_ = FALSE;
		gboolean _tmp34_ = FALSE;
		BoxesInstallerMedia* _tmp35_ = NULL;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = self->priv->machine;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = boxes_libvirt_machine_get_vm_creator (_tmp27_);
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = _tmp28_;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = boxes_vm_creator_get_install_media (_tmp29_);
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = _tmp30_;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = _g_object_ref0 (_tmp31_);
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		media = _tmp32_;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp35_ = media;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp35_, BOXES_TYPE_UNATTENDED_INSTALLER)) {
#line 3752 "libvirt-machine-properties.c"
			BoxesInstallerMedia* _tmp36_ = NULL;
			BoxesUnattendedSetupBox* _tmp37_ = NULL;
			gboolean _tmp38_ = FALSE;
			gboolean _tmp39_ = FALSE;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp36_ = media;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp37_ = (G_TYPE_CHECK_INSTANCE_TYPE (_tmp36_, BOXES_TYPE_UNATTENDED_INSTALLER) ? ((BoxesUnattendedInstaller*) _tmp36_) : NULL)->setup_box;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp38_ = boxes_unattended_setup_box_get_express_install (_tmp37_);
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp39_ = _tmp38_;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp34_ = _tmp39_;
#line 3767 "libvirt-machine-properties.c"
		} else {
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp34_ = FALSE;
#line 3771 "libvirt-machine-properties.c"
		}
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp34_) {
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = TRUE;
#line 3777 "libvirt-machine-properties.c"
		} else {
			gboolean _tmp40_ = FALSE;
			BoxesInstallerMedia* _tmp41_ = NULL;
			OsinfoMedia* _tmp42_ = NULL;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp41_ = media;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp42_ = _tmp41_->os_media;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp42_ != NULL) {
#line 3788 "libvirt-machine-properties.c"
				BoxesInstallerMedia* _tmp43_ = NULL;
				OsinfoMedia* _tmp44_ = NULL;
				gboolean _tmp45_ = FALSE;
				gboolean _tmp46_ = FALSE;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp43_ = media;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp44_ = _tmp43_->os_media;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_object_get (_tmp44_, "live", &_tmp45_, NULL);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp46_ = _tmp45_;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp40_ = _tmp46_;
#line 3803 "libvirt-machine-properties.c"
			} else {
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp40_ = FALSE;
#line 3807 "libvirt-machine-properties.c"
			}
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = _tmp40_;
#line 3811 "libvirt-machine-properties.c"
		}
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp33_) {
#line 3815 "libvirt-machine-properties.c"
			const gchar* _tmp47_ = NULL;
			GtkGrid* _tmp48_ = NULL;
			BoxesProperty* _tmp49_ = NULL;
			BoxesProperty* _tmp50_ = NULL;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp47_ = _ ("CD/DVD");
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp48_ = grid;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp49_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, _tmp47_, (GtkWidget*) _tmp48_, NULL);
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp50_ = _tmp49_;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp50_);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (media);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (source);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (grid);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			block44_data_unref (_data44_);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data44_ = NULL;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 3842 "libvirt-machine-properties.c"
		}
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (media);
#line 3846 "libvirt-machine-properties.c"
	}
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp51_ = (GtkLabel*) gtk_label_new ("");
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp51_);
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_->button_label = _tmp51_;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp52_ = (GtkButton*) gtk_button_new ();
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp52_);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	button = _tmp52_;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp53_ = button;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp54_ = _data44_->button_label;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp53_, (GtkWidget*) _tmp54_);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp55_ = grid;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp56_ = button;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp55_, (GtkWidget*) _tmp56_);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp57_ = _data44_->empty;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp57_) {
#line 3876 "libvirt-machine-properties.c"
		GtkLabel* _tmp58_ = NULL;
		const gchar* _tmp59_ = NULL;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp58_ = _data44_->button_label;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp59_ = _ ("Select");
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text (_tmp58_, _tmp59_);
#line 3885 "libvirt-machine-properties.c"
	} else {
		GtkLabel* _tmp60_ = NULL;
		const gchar* _tmp61_ = NULL;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp60_ = _data44_->button_label;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp61_ = _ ("Remove");
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text (_tmp60_, _tmp61_);
#line 3895 "libvirt-machine-properties.c"
	}
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp62_ = button;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_data (_tmp62_, "clicked", (GCallback) ___lambda132__gtk_button_clicked, block44_data_ref (_data44_), (GClosureNotify) block44_data_unref, 0);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp63_ = _ ("CD/DVD");
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp64_ = grid;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp65_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, _tmp63_, (GtkWidget*) _tmp64_, NULL);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp66_ = _tmp65_;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_tmp66_);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (button);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (source);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (grid);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block44_data_unref (_data44_);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_ = NULL;
#line 3921 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_update_ram_property (BoxesLibvirtMachineProperties* self, BoxesProperty* property) {
	GError * _inner_error_ = NULL;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (property != NULL);
#line 3931 "libvirt-machine-properties.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp0_ = NULL;
		GVirDomain* _tmp1_ = NULL;
		GVirDomain* _tmp2_ = NULL;
		GVirConfigDomain* _tmp3_ = NULL;
		guint64 actual = 0ULL;
		BoxesLibvirtMachine* _tmp4_ = NULL;
		GVirConfigDomain* _tmp5_ = NULL;
		GVirConfigDomain* _tmp6_ = NULL;
		guint64 _tmp7_ = 0ULL;
		guint64 _tmp8_ = 0ULL;
		guint64 pending = 0ULL;
		guint64 _tmp9_ = 0ULL;
		guint64 _tmp10_ = 0ULL;
		guint64 _tmp11_ = 0ULL;
		guint64 _tmp12_ = 0ULL;
		BoxesProperty* _tmp13_ = NULL;
		guint64 _tmp14_ = 0ULL;
		guint64 _tmp15_ = 0ULL;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _tmp1_;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = gvir_domain_get_config (_tmp2_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp3_;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3964 "libvirt-machine-properties.c"
			goto __catch38_g_error;
		}
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = self->priv->machine;
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = boxes_libvirt_machine_get_domain_config (_tmp4_);
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = gvir_config_domain_get_memory (_tmp6_);
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _tmp7_;
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		actual = _tmp8_ / 1024;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = gvir_config_domain_get_memory (config);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		pending = _tmp10_ / 1024;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = actual;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = pending;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:385: RAM actual: %llu, pending: %llu", _tmp11_, _tmp12_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = property;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = actual;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = pending;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_reboot_required (_tmp13_, (_tmp14_ - _tmp15_) > ((guint64) 1));
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 4001 "libvirt-machine-properties.c"
	}
	goto __finally38;
	__catch38_g_error:
	{
		GError* e = NULL;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		e = _inner_error_;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (e);
#line 4013 "libvirt-machine-properties.c"
	}
	__finally38:
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 4024 "libvirt-machine-properties.c"
	}
}


static void boxes_libvirt_machine_properties_mark_recommended_resources_data_free (gpointer _data) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->ram_property);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->storage_property);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_slice_free (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData, _data_);
#line 4040 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_mark_recommended_resources (BoxesLibvirtMachineProperties* self, BoxesSizeProperty* ram_property, BoxesSizeProperty* storage_property, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
	BoxesLibvirtMachineProperties* _tmp0_ = NULL;
	BoxesSizeProperty* _tmp1_ = NULL;
	BoxesSizeProperty* _tmp2_ = NULL;
	BoxesSizeProperty* _tmp3_ = NULL;
	BoxesSizeProperty* _tmp4_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_properties_mark_recommended_resources);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_properties_mark_recommended_resources_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = ram_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->ram_property);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->ram_property = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = storage_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->storage_property);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->storage_property = _tmp4_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_mark_recommended_resources_co (_data_);
#line 4079 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_mark_recommended_resources_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 4087 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_mark_recommended_resources_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = _user_data_;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_source_object_ = source_object;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_res_ = _res_;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_mark_recommended_resources_co (_data_);
#line 4101 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_mark_recommended_resources_co (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_) {
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_data_->_state_) {
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 0:
#line 4110 "libvirt-machine-properties.c"
		goto _state_0;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 1:
#line 4114 "libvirt-machine-properties.c"
		goto _state_1;
		default:
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_assert_not_reached ();
#line 4119 "libvirt-machine-properties.c"
	}
	_state_0:
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = NULL;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = _data_->ram_property;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp1_ == NULL) {
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp2_ = NULL;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp2_ = _data_->storage_property;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp0_ = _data_->_tmp2_ == NULL;
#line 4134 "libvirt-machine-properties.c"
	} else {
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp0_ = FALSE;
#line 4138 "libvirt-machine-properties.c"
	}
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp0_) {
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4146 "libvirt-machine-properties.c"
		} else {
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4150 "libvirt-machine-properties.c"
		}
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4156 "libvirt-machine-properties.c"
	}
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = NULL;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = _data_->self->priv->machine;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_state_ = 1;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_get_os_for_machine (_data_->self, _data_->_tmp3_, boxes_libvirt_machine_properties_mark_recommended_resources_ready, _data_);
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 4168 "libvirt-machine-properties.c"
	_state_1:
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = NULL;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = boxes_libvirt_machine_properties_get_os_for_machine_finish (_data_->self, _data_->_res_);
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->os = _data_->_tmp4_;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = NULL;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = _data_->os;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp5_ == NULL) {
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->os);
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4188 "libvirt-machine-properties.c"
		} else {
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4192 "libvirt-machine-properties.c"
		}
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4198 "libvirt-machine-properties.c"
	}
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = _data_->self->priv->machine;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp6_);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp8_ = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = gvir_config_domain_get_os (_data_->_tmp8_);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp10_ = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp10_ = _data_->_tmp9_;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp11_ = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp11_ = gvir_config_domain_os_get_arch (_data_->_tmp10_);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp12_ = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp12_ = g_strdup (_data_->_tmp11_);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp13_ = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->_tmp10_);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->architecture = _data_->_tmp13_;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp14_ = NULL;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp14_ = _data_->os;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp15_ = NULL;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp15_ = _data_->architecture;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp16_ = NULL;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp16_ = boxes_os_database_get_recommended_resources_for_os (_data_->_tmp14_, _data_->_tmp15_);
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->resources = _data_->_tmp16_;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp17_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp17_ = _data_->resources;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp17_ != NULL) {
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp18_ = NULL;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp18_ = _data_->ram_property;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_tmp18_ != NULL) {
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp19_ = NULL;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp19_ = _data_->ram_property;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp20_ = NULL;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp20_ = _data_->resources;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp21_ = 0LL;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp21_ = osinfo_resources_get_ram (_data_->_tmp20_);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp22_ = 0LL;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp22_ = _data_->_tmp21_;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_size_property_set_recommended (_data_->_tmp19_, (guint64) _data_->_tmp22_);
#line 4280 "libvirt-machine-properties.c"
		}
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp23_ = NULL;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp23_ = _data_->storage_property;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_tmp23_ != NULL) {
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp24_ = NULL;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp24_ = _data_->storage_property;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp25_ = NULL;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp25_ = _data_->resources;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp26_ = 0LL;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp26_ = osinfo_resources_get_storage (_data_->_tmp25_);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp27_ = 0LL;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp27_ = _data_->_tmp26_;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_size_property_set_recommended (_data_->_tmp24_, (guint64) _data_->_tmp27_);
#line 4306 "libvirt-machine-properties.c"
		}
	}
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->resources);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_data_->architecture);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->os);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_state_ == 0) {
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4319 "libvirt-machine-properties.c"
	} else {
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4323 "libvirt-machine-properties.c"
	}
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_unref (_data_->_async_result);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 4329 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_get_os_for_machine_data_free (gpointer _data) {
	BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->machine);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->result);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_slice_free (BoxesLibvirtMachinePropertiesGetOsForMachineData, _data_);
#line 4344 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_get_os_for_machine (BoxesLibvirtMachineProperties* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_;
	BoxesLibvirtMachineProperties* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachinePropertiesGetOsForMachineData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_properties_get_os_for_machine);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_properties_get_os_for_machine_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = machine;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->machine);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->machine = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_get_os_for_machine_co (_data_);
#line 4373 "libvirt-machine-properties.c"
}


static OsinfoOs* boxes_libvirt_machine_properties_get_os_for_machine_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_) {
	OsinfoOs* result;
	BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = _data_->result;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->result = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 4388 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_get_os_for_machine_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = _user_data_;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_source_object_ = source_object;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_res_ = _res_;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_get_os_for_machine_co (_data_);
#line 4402 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_get_os_for_machine_co (BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_) {
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_data_->_state_) {
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 0:
#line 4411 "libvirt-machine-properties.c"
		goto _state_0;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 1:
#line 4415 "libvirt-machine-properties.c"
		goto _state_1;
		default:
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_assert_not_reached ();
#line 4420 "libvirt-machine-properties.c"
	}
	_state_0:
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp0_ = NULL;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp0_ = _data_->machine;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = NULL;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp0_);
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp2_ = NULL;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = NULL;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = boxes_vm_configurator_get_os_id (_data_->_tmp2_);
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->os_id = _data_->_tmp3_;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = NULL;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = _data_->os_id;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp4_ == NULL) {
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->result = NULL;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data_->os_id);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4455 "libvirt-machine-properties.c"
		} else {
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4459 "libvirt-machine-properties.c"
		}
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4465 "libvirt-machine-properties.c"
	}
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = NULL;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = boxes_media_manager_get_instance ();
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = NULL;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = NULL;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = boxes_media_manager_get_os_db (_data_->_tmp6_);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp8_ = NULL;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = NULL;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = _g_object_ref0 (_data_->_tmp8_);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp10_ = NULL;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp10_ = _data_->_tmp9_;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->_tmp6_);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->os_db = _data_->_tmp10_;
#line 4495 "libvirt-machine-properties.c"
	{
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp12_ = NULL;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp12_ = _data_->os_db;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp13_ = NULL;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp13_ = _data_->os_id;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_state_ = 1;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_os_database_get_os_by_id (_data_->_tmp12_, _data_->_tmp13_, boxes_libvirt_machine_properties_get_os_for_machine_ready, _data_);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4511 "libvirt-machine-properties.c"
		_state_1:
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp14_ = NULL;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp14_ = boxes_os_database_get_os_by_id_finish (_data_->_tmp12_, _data_->_res_, &_data_->_inner_error_);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp11_ = _data_->_tmp14_;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_data_->_inner_error_->domain == BOXES_OS_DATABASE_ERROR) {
#line 4523 "libvirt-machine-properties.c"
				goto __catch39_boxes_os_database_error;
			}
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_data_->os_db);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_data_->os_id);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_data_->_inner_error_);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return FALSE;
#line 4536 "libvirt-machine-properties.c"
		}
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp15_ = NULL;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp15_ = _data_->_tmp11_;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp11_ = NULL;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->result = _data_->_tmp15_;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->_tmp11_);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->os_db);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data_->os_id);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4556 "libvirt-machine-properties.c"
		} else {
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4560 "libvirt-machine-properties.c"
		}
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4566 "libvirt-machine-properties.c"
	}
	goto __finally39;
	__catch39_boxes_os_database_error:
	{
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_inner_error_ = NULL;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp16_ = NULL;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp16_ = _data_->os_id;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp17_ = NULL;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp17_ = _data_->_error_;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp18_ = NULL;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp18_ = _data_->_tmp17_->message;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:419: Failed to find OS with ID '%s': %" \
"s", _data_->_tmp16_, _data_->_tmp18_);
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->result = NULL;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_data_->_error_);
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->os_db);
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data_->os_id);
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4601 "libvirt-machine-properties.c"
		} else {
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4605 "libvirt-machine-properties.c"
		}
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4611 "libvirt-machine-properties.c"
	}
	__finally39:
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->os_db);
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_data_->os_id);
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_data_->_inner_error_);
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->os_db);
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_data_->os_id);
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_state_ == 0) {
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4632 "libvirt-machine-properties.c"
	} else {
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4636 "libvirt-machine-properties.c"
	}
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_unref (_data_->_async_result);
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 4642 "libvirt-machine-properties.c"
}


static Block46Data* block46_data_ref (Block46Data* _data46_) {
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data46_->_ref_count_);
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data46_;
#line 4651 "libvirt-machine-properties.c"
}


static void block46_data_unref (void * _userdata_) {
	Block46Data* _data46_;
	_data46_ = (Block46Data*) _userdata_;
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data46_->_ref_count_)) {
#line 4660 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data46_->self;
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data46_->property);
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block46Data, _data46_);
#line 4670 "libvirt-machine-properties.c"
	}
}


static void _boxes_libvirt_machine_properties_on_ram_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self) {
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_on_ram_changed ((BoxesLibvirtMachineProperties*) self, _sender, value);
#line 4678 "libvirt-machine-properties.c"
}


static void ___lambda125_ (Block46Data* _data46_) {
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data46_->self;
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_machine_is_on ((BoxesMachine*) _tmp0_);
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (!_tmp1_) {
#line 4694 "libvirt-machine-properties.c"
		BoxesSizeProperty* _tmp2_ = NULL;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _data46_->property;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_reboot_required ((BoxesProperty*) _tmp2_, FALSE);
#line 4700 "libvirt-machine-properties.c"
	}
}


static void ____lambda125__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda125_ (self);
#line 4708 "libvirt-machine-properties.c"
}


static BoxesSizeProperty* boxes_libvirt_machine_properties_add_ram_property (BoxesLibvirtMachineProperties* self, GList** list) {
	BoxesSizeProperty* result = NULL;
	GError * _inner_error_ = NULL;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 4717 "libvirt-machine-properties.c"
	{
		Block46Data* _data46_;
		GVirNodeInfo* _tmp0_ = NULL;
		BoxesLibvirtMachine* _tmp1_ = NULL;
		GVirConnection* _tmp2_ = NULL;
		GVirConnection* _tmp3_ = NULL;
		GVirNodeInfo* _tmp4_ = NULL;
		gulong max_ram = 0UL;
		GVirNodeInfo* _tmp5_ = NULL;
		GVirNodeInfo* _tmp6_ = NULL;
		gulong _tmp7_ = 0UL;
		gulong _tmp8_ = 0UL;
		const gchar* _tmp9_ = NULL;
		BoxesLibvirtMachine* _tmp10_ = NULL;
		GVirConfigDomain* _tmp11_ = NULL;
		GVirConfigDomain* _tmp12_ = NULL;
		guint64 _tmp13_ = 0ULL;
		guint64 _tmp14_ = 0ULL;
		gulong _tmp15_ = 0UL;
		BoxesSizeProperty* _tmp16_ = NULL;
		gboolean _tmp17_ = FALSE;
		gboolean _tmp18_ = FALSE;
		BoxesLibvirtMachine* _tmp19_ = NULL;
		GVirConfigDomain* _tmp20_ = NULL;
		GVirConfigDomain* _tmp21_ = NULL;
		gboolean _tmp22_ = FALSE;
		BoxesLibvirtMachine* _tmp34_ = NULL;
		BoxesSizeProperty* _tmp35_ = NULL;
		BoxesSizeProperty* _tmp36_ = NULL;
		BoxesSizeProperty* _tmp37_ = NULL;
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data46_ = g_slice_new0 (Block46Data);
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data46_->_ref_count_ = 1;
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data46_->self = g_object_ref (self);
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = self->priv->machine;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = boxes_libvirt_machine_get_connection (_tmp1_);
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _tmp2_;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = gvir_connection_get_node_info (_tmp3_, &_inner_error_);
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _tmp4_;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			block46_data_unref (_data46_);
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data46_ = NULL;
#line 4770 "libvirt-machine-properties.c"
			goto __catch40_g_error;
		}
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _tmp0_;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = NULL;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = _tmp6_->memory;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _tmp7_;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirNodeInfo_free0 (_tmp6_);
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		max_ram = _tmp8_;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = _ ("Memory");
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = self->priv->machine;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = boxes_libvirt_machine_get_domain_config (_tmp10_);
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = _tmp11_;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = gvir_config_domain_get_memory (_tmp12_);
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _tmp13_;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = max_ram;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = boxes_iproperties_provider_add_size_property ((BoxesIPropertiesProvider*) self, list, _tmp9_, _tmp14_ * OSINFO_KIBIBYTES, (guint64) (64 * OSINFO_MEBIBYTES), (guint64) (_tmp15_ * OSINFO_KIBIBYTES), (guint64) (64 * OSINFO_MEBIBYTES), G_FORMAT_SIZE_IEC_UNITS);
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data46_->property = _tmp16_;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = self->priv->machine;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = boxes_libvirt_machine_get_domain_config (_tmp19_);
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = _tmp20_;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = boxes_vm_configurator_is_install_config (_tmp21_);
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp22_) {
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = TRUE;
#line 4817 "libvirt-machine-properties.c"
		} else {
			BoxesLibvirtMachine* _tmp23_ = NULL;
			GVirConfigDomain* _tmp24_ = NULL;
			GVirConfigDomain* _tmp25_ = NULL;
			gboolean _tmp26_ = FALSE;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp23_ = self->priv->machine;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = boxes_libvirt_machine_get_domain_config (_tmp23_);
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = _tmp24_;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = boxes_vm_configurator_is_live_config (_tmp25_);
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = _tmp26_;
#line 4833 "libvirt-machine-properties.c"
		}
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp18_) {
#line 4837 "libvirt-machine-properties.c"
			BoxesLibvirtMachine* _tmp27_ = NULL;
			BoxesAppWindow* _tmp28_ = NULL;
			BoxesAppWindow* _tmp29_ = NULL;
			BoxesUIState _tmp30_ = 0;
			BoxesUIState _tmp31_ = 0;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = self->priv->machine;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp28_ = boxes_machine_get_window ((BoxesMachine*) _tmp27_);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp29_ = _tmp28_;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp30_ = boxes_ui_get_previous_ui_state ((BoxesUI*) _tmp29_);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp31_ = _tmp30_;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = _tmp31_ != BOXES_UI_STATE_WIZARD;
#line 4855 "libvirt-machine-properties.c"
		} else {
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = FALSE;
#line 4859 "libvirt-machine-properties.c"
		}
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp17_) {
#line 4863 "libvirt-machine-properties.c"
			BoxesSizeProperty* _tmp32_ = NULL;
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = _data46_->property;
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_property_set_sensitive ((BoxesProperty*) _tmp32_, FALSE);
#line 4869 "libvirt-machine-properties.c"
		} else {
			BoxesSizeProperty* _tmp33_ = NULL;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = _data46_->property;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp33_, "changed", (GCallback) _boxes_libvirt_machine_properties_on_ram_changed_boxes_size_property_changed, self, 0);
#line 4876 "libvirt-machine-properties.c"
		}
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp34_ = self->priv->machine;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_connect_data ((GObject*) _tmp34_, "notify::state", (GCallback) ____lambda125__g_object_notify, block46_data_ref (_data46_), (GClosureNotify) block46_data_unref, 0);
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp35_ = _data46_->property;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_update_ram_property (self, (BoxesProperty*) _tmp35_);
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp36_ = _data46_->property;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp37_ = _g_object_ref0 (_tmp36_);
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = _tmp37_;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirNodeInfo_free0 (_tmp0_);
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block46_data_unref (_data46_);
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data46_ = NULL;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 4900 "libvirt-machine-properties.c"
	}
	goto __finally40;
	__catch40_g_error:
	{
		GError* _error_ = NULL;
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = NULL;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 4916 "libvirt-machine-properties.c"
	}
	__finally40:
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_inner_error_);
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return NULL;
#line 4925 "libvirt-machine-properties.c"
}


static Block47Data* block47_data_ref (Block47Data* _data47_) {
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data47_->_ref_count_);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data47_;
#line 4934 "libvirt-machine-properties.c"
}


static void block47_data_unref (void * _userdata_) {
	Block47Data* _data47_;
	_data47_ = (Block47Data*) _userdata_;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data47_->_ref_count_)) {
#line 4943 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data47_->self;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data47_->property);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block47Data, _data47_);
#line 4953 "libvirt-machine-properties.c"
	}
}


static gboolean __lambda124_ (Block47Data* _data47_) {
	BoxesLibvirtMachineProperties* self;
	gboolean result = FALSE;
	guint64 ram = 0ULL;
	guint64 _tmp0_ = 0ULL;
	BoxesProperty* _tmp24_ = NULL;
	GError * _inner_error_ = NULL;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data47_->self;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data47_->value;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	ram = ((_tmp0_ + OSINFO_KIBIBYTES) - 1) / OSINFO_KIBIBYTES;
#line 4971 "libvirt-machine-properties.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp1_ = NULL;
		GVirDomain* _tmp2_ = NULL;
		GVirDomain* _tmp3_ = NULL;
		GVirConfigDomain* _tmp4_ = NULL;
		GVirConfigDomain* _tmp5_ = NULL;
		guint64 _tmp6_ = 0ULL;
		GVirConfigDomain* _tmp7_ = NULL;
		GObjectClass* _tmp8_ = NULL;
		GParamSpec* _tmp9_ = NULL;
		BoxesLibvirtMachine* _tmp12_ = NULL;
		GVirDomain* _tmp13_ = NULL;
		GVirDomain* _tmp14_ = NULL;
		GVirConfigDomain* _tmp15_ = NULL;
		guint64 _tmp16_ = 0ULL;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = self->priv->machine;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = boxes_libvirt_machine_get_domain (_tmp1_);
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _tmp2_;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = gvir_domain_get_config (_tmp3_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp4_;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5000 "libvirt-machine-properties.c"
			goto __catch41_g_error;
		}
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = config;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = ram;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_set_memory (_tmp5_, _tmp6_);
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = config;
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = G_OBJECT_GET_CLASS ((GObject*) _tmp7_);
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = g_object_class_find_property (_tmp8_, "current-memory");
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp9_ != NULL) {
#line 5017 "libvirt-machine-properties.c"
			GVirConfigDomain* _tmp10_ = NULL;
			guint64 _tmp11_ = 0ULL;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = config;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = ram;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_set ((GObject*) _tmp10_, "current-memory", _tmp11_, NULL);
#line 5026 "libvirt-machine-properties.c"
		}
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = self->priv->machine;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = boxes_libvirt_machine_get_domain (_tmp12_);
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _tmp13_;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = config;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_domain_set_config (_tmp14_, _tmp15_, &_inner_error_);
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 5042 "libvirt-machine-properties.c"
			goto __catch41_g_error;
		}
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = ram;
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:465: RAM changed to %llu KiB", _tmp16_);
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 5051 "libvirt-machine-properties.c"
	}
	goto __finally41;
	__catch41_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp17_ = NULL;
		GVirDomain* _tmp18_ = NULL;
		GVirDomain* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
		guint64 _tmp21_ = 0ULL;
		GError* _tmp22_ = NULL;
		const gchar* _tmp23_ = NULL;
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = self->priv->machine;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = boxes_libvirt_machine_get_domain (_tmp17_);
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = gvir_domain_get_name (_tmp19_);
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = ram;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = _error_;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = _tmp22_->message;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:467: Failed to change RAM of box '%s' " \
"to %llu KiB: %s", _tmp20_, _tmp21_, _tmp23_);
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 5086 "libvirt-machine-properties.c"
	}
	__finally41:
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 5097 "libvirt-machine-properties.c"
	}
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp24_ = _data47_->property;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_update_ram_property (self, _tmp24_);
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = FALSE;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 5107 "libvirt-machine-properties.c"
}


static gboolean ___lambda124__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda124_ (self);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 5116 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_on_ram_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value) {
	Block47Data* _data47_;
	BoxesProperty* _tmp0_ = NULL;
	BoxesProperty* _tmp1_ = NULL;
	guint64 _tmp2_ = 0ULL;
	BoxesProperty* _tmp3_ = NULL;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (property != NULL);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_ = g_slice_new0 (Block47Data);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_->_ref_count_ = 1;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_->self = g_object_ref (self);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = property;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data47_->property);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_->property = _tmp1_;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = value;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_->value = _tmp2_;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _data47_->property;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_property_set_deferred_change (_tmp3_, ___lambda124__gsource_func, block47_data_ref (_data47_), block47_data_unref);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block47_data_unref (_data47_);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_ = NULL;
#line 5156 "libvirt-machine-properties.c"
}


static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self) {
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_storage_vol_info_get_type (), self);
#line 5163 "libvirt-machine-properties.c"
}


static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self) {
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_storage_pool_info_get_type (), self);
#line 5170 "libvirt-machine-properties.c"
}


static void _boxes_libvirt_machine_properties_on_storage_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_on_storage_changed ((BoxesLibvirtMachineProperties*) self, _sender, value);
#line 5177 "libvirt-machine-properties.c"
}


static BoxesSizeProperty* boxes_libvirt_machine_properties_add_storage_property (BoxesLibvirtMachineProperties* self, GList** list) {
	BoxesSizeProperty* result = NULL;
	gboolean _tmp0_ = FALSE;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GError * _inner_error_ = NULL;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_libvirt_machine_get_importing (_tmp1_);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp3_) {
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = TRUE;
#line 5200 "libvirt-machine-properties.c"
	} else {
		BoxesLibvirtMachine* _tmp4_ = NULL;
		GVirStorageVol* _tmp5_ = NULL;
		GVirStorageVol* _tmp6_ = NULL;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = self->priv->machine;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = boxes_libvirt_machine_get_storage_volume (_tmp4_);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _tmp6_ == NULL;
#line 5213 "libvirt-machine-properties.c"
	}
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_) {
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = NULL;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5221 "libvirt-machine-properties.c"
	}
	{
		GVirStorageVolInfo* volume_info = NULL;
		BoxesLibvirtMachine* _tmp7_ = NULL;
		GVirStorageVol* _tmp8_ = NULL;
		GVirStorageVol* _tmp9_ = NULL;
		GVirStorageVolInfo* _tmp10_ = NULL;
		GVirStoragePool* pool = NULL;
		BoxesLibvirtMachine* _tmp11_ = NULL;
		GVirConnection* _tmp12_ = NULL;
		GVirConnection* _tmp13_ = NULL;
		GVirStoragePool* _tmp14_ = NULL;
		GVirStoragePoolInfo* pool_info = NULL;
		GVirStoragePool* _tmp15_ = NULL;
		GVirStoragePoolInfo* _tmp16_ = NULL;
		guint64 min_storage = 0ULL;
		guint64 _tmp17_ = 0ULL;
		guint64 max_storage = 0ULL;
		GVirStorageVolInfo* _tmp18_ = NULL;
		guint64 _tmp19_ = 0ULL;
		GVirStoragePoolInfo* _tmp20_ = NULL;
		guint64 _tmp21_ = 0ULL;
		guint64 _tmp22_ = 0ULL;
		guint64 _tmp23_ = 0ULL;
		BoxesSizeProperty* property = NULL;
		const gchar* _tmp52_ = NULL;
		GVirStorageVolInfo* _tmp53_ = NULL;
		guint64 _tmp54_ = 0ULL;
		guint64 _tmp55_ = 0ULL;
		guint64 _tmp56_ = 0ULL;
		BoxesSizeProperty* _tmp57_ = NULL;
		BoxesSizeProperty* _tmp58_ = NULL;
		gboolean _tmp59_ = FALSE;
		gboolean _tmp60_ = FALSE;
		BoxesLibvirtMachine* _tmp61_ = NULL;
		GVirConfigDomain* _tmp62_ = NULL;
		GVirConfigDomain* _tmp63_ = NULL;
		gboolean _tmp64_ = FALSE;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = self->priv->machine;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = boxes_libvirt_machine_get_storage_volume (_tmp7_);
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = _tmp8_;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = gvir_storage_vol_get_info (_tmp9_, &_inner_error_);
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		volume_info = _tmp10_;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5272 "libvirt-machine-properties.c"
			goto __catch42_g_error;
		}
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = self->priv->machine;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = boxes_libvirt_machine_get_connection (_tmp11_);
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = _tmp12_;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = boxes_get_storage_pool (_tmp13_);
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		pool = _tmp14_;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = pool;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = gvir_storage_pool_get_info (_tmp15_, &_inner_error_);
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		pool_info = _tmp16_;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (pool);
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 5297 "libvirt-machine-properties.c"
			goto __catch42_g_error;
		}
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = boxes_libvirt_machine_properties_get_minimum_disk_size (self, &_inner_error_);
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		min_storage = _tmp17_;
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStoragePoolInfo_free0 (pool_info);
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (pool);
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 5312 "libvirt-machine-properties.c"
			goto __catch42_g_error;
		}
#line 488 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = volume_info;
#line 488 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_->allocation;
#line 488 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = pool_info;
#line 488 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = _tmp20_->available;
#line 488 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		max_storage = _tmp19_ + _tmp21_;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = min_storage;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = max_storage;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp22_ >= _tmp23_) {
#line 5331 "libvirt-machine-properties.c"
			const gchar* _tmp24_ = NULL;
			GVirStorageVolInfo* _tmp25_ = NULL;
			guint64 _tmp26_ = 0ULL;
			gchar* _tmp27_ = NULL;
			gchar* _tmp28_ = NULL;
			gchar* _tmp29_ = NULL;
			gchar* _tmp30_ = NULL;
			BoxesStringProperty* _tmp31_ = NULL;
			BoxesStringProperty* _tmp32_ = NULL;
			GtkInfoBar* infobar = NULL;
			GtkInfoBar* _tmp33_ = NULL;
			GtkInfoBar* _tmp34_ = NULL;
			GtkContainer* content = NULL;
			GtkInfoBar* _tmp35_ = NULL;
			GtkContainer* _tmp36_ = NULL;
			GtkContainer* _tmp37_ = NULL;
			GtkImage* image = NULL;
			GtkImage* _tmp38_ = NULL;
			GtkImage* _tmp39_ = NULL;
			GtkImage* _tmp40_ = NULL;
			GtkContainer* _tmp41_ = NULL;
			GtkImage* _tmp42_ = NULL;
			gchar* msg = NULL;
			const gchar* _tmp43_ = NULL;
			gchar* _tmp44_ = NULL;
			GtkLabel* label = NULL;
			const gchar* _tmp45_ = NULL;
			GtkLabel* _tmp46_ = NULL;
			GtkContainer* _tmp47_ = NULL;
			GtkLabel* _tmp48_ = NULL;
			GtkInfoBar* _tmp49_ = NULL;
			BoxesProperty* _tmp50_ = NULL;
			BoxesProperty* _tmp51_ = NULL;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = _ ("Maximum Disk Size");
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = volume_info;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = _tmp25_->capacity;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = g_format_size_full (_tmp26_, G_FORMAT_SIZE_DEFAULT);
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp28_ = _tmp27_;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp29_ = g_strdup_printf ("%s", _tmp28_);
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp30_ = _tmp29_;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp31_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, list, _tmp24_, _tmp30_);
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = _tmp31_;
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp32_);
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp30_);
#line 491 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp28_);
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = (GtkInfoBar*) gtk_info_bar_new ();
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_ref_sink (_tmp33_);
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			infobar = _tmp33_;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp34_ = infobar;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_info_bar_set_message_type (_tmp34_, GTK_MESSAGE_WARNING);
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp35_ = infobar;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp36_ = gtk_info_bar_get_content_area (_tmp35_);
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp37_ = _g_object_ref0 (_tmp36_);
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			content = _tmp37_;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp38_ = (GtkImage*) gtk_image_new ();
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_ref_sink (_tmp38_);
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			image = _tmp38_;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp39_ = image;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_set (_tmp39_, "icon-name", "dialog-warning", NULL);
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp40_ = image;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_set (_tmp40_, "icon-size", 3, NULL);
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp41_ = content;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp42_ = image;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_container_add (_tmp41_, (GtkWidget*) _tmp42_);
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp43_ = _ ("There is not enough space on your machine to increase the maximum disk" \
" size.");
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp44_ = g_strdup (_tmp43_);
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			msg = _tmp44_;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp45_ = msg;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp46_ = (GtkLabel*) gtk_label_new (_tmp45_);
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_ref_sink (_tmp46_);
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			label = _tmp46_;
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp47_ = content;
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp48_ = label;
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_container_add (_tmp47_, (GtkWidget*) _tmp48_);
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp49_ = infobar;
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp50_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, NULL, (GtkWidget*) _tmp49_, NULL);
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp51_ = _tmp50_;
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp51_);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			result = NULL;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (label);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (msg);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (image);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (content);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (infobar);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStoragePoolInfo_free0 (pool_info);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (pool);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return result;
#line 5475 "libvirt-machine-properties.c"
		}
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp52_ = _ ("Maximum Disk Size");
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp53_ = volume_info;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp54_ = _tmp53_->capacity;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp55_ = min_storage;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp56_ = max_storage;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp57_ = boxes_iproperties_provider_add_size_property ((BoxesIPropertiesProvider*) self, list, _tmp52_, _tmp54_, _tmp55_, _tmp56_, 256 * BOXES_LIBVIRT_MACHINE_PROPERTIES_MEGABYTES, G_FORMAT_SIZE_DEFAULT);
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		property = _tmp57_;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp58_ = property;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_defer_interval ((BoxesProperty*) _tmp58_, (guint) 0);
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp61_ = self->priv->machine;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp62_ = boxes_libvirt_machine_get_domain_config (_tmp61_);
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp63_ = _tmp62_;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp64_ = boxes_vm_configurator_is_install_config (_tmp63_);
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp64_) {
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp60_ = TRUE;
#line 5507 "libvirt-machine-properties.c"
		} else {
			BoxesLibvirtMachine* _tmp65_ = NULL;
			GVirConfigDomain* _tmp66_ = NULL;
			GVirConfigDomain* _tmp67_ = NULL;
			gboolean _tmp68_ = FALSE;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp65_ = self->priv->machine;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp66_ = boxes_libvirt_machine_get_domain_config (_tmp65_);
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp67_ = _tmp66_;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp68_ = boxes_vm_configurator_is_live_config (_tmp67_);
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp60_ = _tmp68_;
#line 5523 "libvirt-machine-properties.c"
		}
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp60_) {
#line 5527 "libvirt-machine-properties.c"
			BoxesLibvirtMachine* _tmp69_ = NULL;
			BoxesAppWindow* _tmp70_ = NULL;
			BoxesAppWindow* _tmp71_ = NULL;
			BoxesUIState _tmp72_ = 0;
			BoxesUIState _tmp73_ = 0;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp69_ = self->priv->machine;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp70_ = boxes_machine_get_window ((BoxesMachine*) _tmp69_);
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp71_ = _tmp70_;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp72_ = boxes_ui_get_previous_ui_state ((BoxesUI*) _tmp71_);
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp73_ = _tmp72_;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp59_ = _tmp73_ != BOXES_UI_STATE_WIZARD;
#line 5545 "libvirt-machine-properties.c"
		} else {
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp59_ = FALSE;
#line 5549 "libvirt-machine-properties.c"
		}
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp59_) {
#line 5553 "libvirt-machine-properties.c"
			BoxesSizeProperty* _tmp74_ = NULL;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp74_ = property;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_property_set_sensitive ((BoxesProperty*) _tmp74_, FALSE);
#line 5559 "libvirt-machine-properties.c"
		} else {
			BoxesSizeProperty* _tmp75_ = NULL;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp75_ = property;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp75_, "changed", (GCallback) _boxes_libvirt_machine_properties_on_storage_changed_boxes_size_property_changed, self, 0);
#line 5566 "libvirt-machine-properties.c"
		}
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = property;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStoragePoolInfo_free0 (pool_info);
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (pool);
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5578 "libvirt-machine-properties.c"
	}
	goto __finally42;
	__catch42_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp76_ = NULL;
		GVirStorageVol* _tmp77_ = NULL;
		GVirStorageVol* _tmp78_ = NULL;
		const gchar* _tmp79_ = NULL;
		GError* _tmp80_ = NULL;
		const gchar* _tmp81_ = NULL;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp76_ = self->priv->machine;
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp77_ = boxes_libvirt_machine_get_storage_volume (_tmp76_);
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp78_ = _tmp77_;
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp79_ = gvir_storage_vol_get_name (_tmp78_);
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp80_ = _error_;
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp81_ = _tmp80_->message;
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:532: Failed to get information on volu" \
"me '%s' or it's parent pool: %s", _tmp79_, _tmp81_);
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = NULL;
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5614 "libvirt-machine-properties.c"
	}
	__finally42:
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_inner_error_);
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return NULL;
#line 5623 "libvirt-machine-properties.c"
}


static Block48Data* block48_data_ref (Block48Data* _data48_) {
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data48_->_ref_count_);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data48_;
#line 5632 "libvirt-machine-properties.c"
}


static void block48_data_unref (void * _userdata_) {
	Block48Data* _data48_;
	_data48_ = (Block48Data*) _userdata_;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data48_->_ref_count_)) {
#line 5641 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data48_->self;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block48Data, _data48_);
#line 5649 "libvirt-machine-properties.c"
	}
}


static Block49Data* block49_data_ref (Block49Data* _data49_) {
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data49_->_ref_count_);
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data49_;
#line 5659 "libvirt-machine-properties.c"
}


static void block49_data_unref (void * _userdata_) {
	Block49Data* _data49_;
	_data49_ = (Block49Data*) _userdata_;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data49_->_ref_count_)) {
#line 5668 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data49_->_data48_->self;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data49_->pool);
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block48_data_unref (_data49_->_data48_);
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data49_->_data48_ = NULL;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block49Data, _data49_);
#line 5680 "libvirt-machine-properties.c"
	}
}


static void _____lambda127_ (Block49Data* _data49_, GObject* obj, GAsyncResult* res) {
	Block48Data* _data48_;
	BoxesLibvirtMachineProperties* self;
	GError * _inner_error_ = NULL;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_ = _data49_->_data48_;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data48_->self;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (res != NULL);
#line 5695 "libvirt-machine-properties.c"
	{
		GVirStoragePool* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
		BoxesLibvirtMachine* _tmp2_ = NULL;
		guint64 _tmp3_ = 0ULL;
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _data49_->pool;
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = res;
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_storage_pool_refresh_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5709 "libvirt-machine-properties.c"
			goto __catch44_g_error;
		}
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = self->priv->machine;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_update_domain_config (_tmp2_);
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _data49_->size;
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:557: Storage changed to %llu KiB", _tmp3_);
#line 5720 "libvirt-machine-properties.c"
	}
	goto __finally44;
	__catch44_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp4_ = NULL;
		GVirStorageVol* _tmp5_ = NULL;
		GVirStorageVol* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		guint64 _tmp8_ = 0ULL;
		GError* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = self->priv->machine;
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = boxes_libvirt_machine_get_storage_volume (_tmp4_);
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = gvir_storage_vol_get_name (_tmp6_);
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _data49_->size;
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = _error_;
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_->message;
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:559: Failed to change storage capacity" \
" of volume '%s' to %llu KiB: %s", _tmp7_, _tmp8_, _tmp10_);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 5755 "libvirt-machine-properties.c"
	}
	__finally44:
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 5766 "libvirt-machine-properties.c"
	}
}


static void ______lambda127__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_____lambda127_ (self, source_object, res);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block49_data_unref (self);
#line 5776 "libvirt-machine-properties.c"
}


static gboolean __lambda126_ (Block48Data* _data48_) {
	BoxesLibvirtMachineProperties* self;
	gboolean result = FALSE;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirStorageVol* _tmp1_ = NULL;
	GVirStorageVol* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data48_->self;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_storage_volume (_tmp0_);
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp2_ == NULL) {
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = FALSE;
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5801 "libvirt-machine-properties.c"
	}
	{
		BoxesLibvirtMachine* _tmp3_ = NULL;
		gboolean _tmp4_ = FALSE;
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = self->priv->machine;
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = boxes_machine_is_running ((BoxesMachine*) _tmp3_);
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp4_) {
#line 5812 "libvirt-machine-properties.c"
			GVirDomainDisk* disk = NULL;
			BoxesLibvirtMachine* _tmp5_ = NULL;
			GVirDomainDisk* _tmp6_ = NULL;
			GVirDomainDisk* _tmp7_ = NULL;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp5_ = self->priv->machine;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6_ = boxes_libvirt_machine_get_domain_disk (_tmp5_, &_inner_error_);
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			disk = _tmp6_;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5825 "libvirt-machine-properties.c"
				goto __catch43_g_error;
			}
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp7_ = disk;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp7_ != NULL) {
#line 5832 "libvirt-machine-properties.c"
				Block49Data* _data49_;
				guint64 _tmp8_ = 0ULL;
				GVirDomainDisk* _tmp9_ = NULL;
				guint64 _tmp10_ = 0ULL;
				BoxesLibvirtMachine* _tmp11_ = NULL;
				GVirConnection* _tmp12_ = NULL;
				GVirConnection* _tmp13_ = NULL;
				GVirStoragePool* _tmp14_ = NULL;
				GVirStoragePool* _tmp15_ = NULL;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data49_ = g_slice_new0 (Block49Data);
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data49_->_ref_count_ = 1;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data49_->_data48_ = block48_data_ref (_data48_);
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp8_ = _data48_->value;
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data49_->size = ((_tmp8_ + OSINFO_KIBIBYTES) - 1) / OSINFO_KIBIBYTES;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp9_ = disk;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp10_ = _data49_->size;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				gvir_domain_disk_resize (_tmp9_, _tmp10_, (guint) 0, &_inner_error_);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					block49_data_unref (_data49_);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_data49_ = NULL;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_g_object_unref0 (disk);
#line 5866 "libvirt-machine-properties.c"
					goto __catch43_g_error;
				}
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp11_ = self->priv->machine;
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp12_ = boxes_libvirt_machine_get_connection (_tmp11_);
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp13_ = _tmp12_;
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp14_ = boxes_get_storage_pool (_tmp13_);
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data49_->pool = _tmp14_;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp15_ = _data49_->pool;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				gvir_storage_pool_refresh_async (_tmp15_, NULL, ______lambda127__gasync_ready_callback, block49_data_ref (_data49_));
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				block49_data_unref (_data49_);
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data49_ = NULL;
#line 5887 "libvirt-machine-properties.c"
			}
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (disk);
#line 5891 "libvirt-machine-properties.c"
		} else {
			guint64 _tmp16_ = 0ULL;
			guint64 _tmp17_ = 0ULL;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = _data48_->value;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_properties_resize_storage_volume (self, _tmp16_, &_inner_error_);
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5901 "libvirt-machine-properties.c"
				goto __catch43_g_error;
			}
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = _data48_->value;
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_debug ("libvirt-machine-properties.vala:568: Storage changed to %llu", _tmp17_);
#line 5908 "libvirt-machine-properties.c"
		}
	}
	goto __finally43;
	__catch43_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp18_ = NULL;
		GVirStorageVol* _tmp19_ = NULL;
		GVirStorageVol* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		guint64 _tmp22_ = 0ULL;
		GError* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = self->priv->machine;
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = boxes_libvirt_machine_get_storage_volume (_tmp18_);
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = _tmp19_;
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = gvir_storage_vol_get_name (_tmp20_);
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = _data48_->value;
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = _error_;
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = _tmp23_->message;
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:571: Failed to change storage capacity" \
" of volume '%s' to %llu: %s", _tmp21_, _tmp22_, _tmp24_);
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 5944 "libvirt-machine-properties.c"
	}
	__finally43:
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 5955 "libvirt-machine-properties.c"
	}
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = FALSE;
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 5961 "libvirt-machine-properties.c"
}


static gboolean ___lambda126__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda126_ (self);
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 5970 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_on_storage_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value) {
	Block48Data* _data48_;
	guint64 _tmp0_ = 0ULL;
	BoxesProperty* _tmp1_ = NULL;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (property != NULL);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_ = g_slice_new0 (Block48Data);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_->_ref_count_ = 1;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_->self = g_object_ref (self);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = value;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_->value = _tmp0_;
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = property;
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_property_set_deferred_change (_tmp1_, ___lambda126__gsource_func, block48_data_ref (_data48_), block48_data_unref);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block48_data_unref (_data48_);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_ = NULL;
#line 6000 "libvirt-machine-properties.c"
}


static guint64 boxes_libvirt_machine_properties_get_minimum_disk_size (BoxesLibvirtMachineProperties* self, GError** error) {
	guint64 result = 0ULL;
	GVirStorageVolInfo* volume_info = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirStorageVol* _tmp1_ = NULL;
	GVirStorageVol* _tmp2_ = NULL;
	GVirStorageVolInfo* _tmp3_ = NULL;
	BoxesLibvirtMachine* _tmp4_ = NULL;
	BoxesVMCreator* _tmp5_ = NULL;
	BoxesVMCreator* _tmp6_ = NULL;
	OsinfoResources* minimum_resources = NULL;
	BoxesLibvirtMachine* _tmp9_ = NULL;
	BoxesVMCreator* _tmp10_ = NULL;
	BoxesVMCreator* _tmp11_ = NULL;
	BoxesInstallerMedia* _tmp12_ = NULL;
	BoxesInstallerMedia* _tmp13_ = NULL;
	OsinfoOs* _tmp14_ = NULL;
	gboolean _tmp33_ = FALSE;
	OsinfoResources* _tmp34_ = NULL;
	GError * _inner_error_ = NULL;
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, 0ULL);
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_storage_volume (_tmp0_);
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = gvir_storage_vol_get_info (_tmp2_, &_inner_error_);
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	volume_info = _tmp3_;
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return 0ULL;
#line 6042 "libvirt-machine-properties.c"
	}
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = self->priv->machine;
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = boxes_libvirt_machine_get_vm_creator (_tmp4_);
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = _tmp5_;
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp6_ == NULL) {
#line 6052 "libvirt-machine-properties.c"
		GVirStorageVolInfo* _tmp7_ = NULL;
		guint64 _tmp8_ = 0ULL;
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = volume_info;
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _tmp7_->capacity;
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = _tmp8_;
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 6065 "libvirt-machine-properties.c"
	}
#line 589 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	minimum_resources = NULL;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = self->priv->machine;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = boxes_libvirt_machine_get_vm_creator (_tmp9_);
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = _tmp10_;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp12_ = boxes_vm_creator_get_install_media (_tmp11_);
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = _tmp12_;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp14_ = _tmp13_->os;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp14_ != NULL) {
#line 6083 "libvirt-machine-properties.c"
		OsinfoOs* os = NULL;
		BoxesLibvirtMachine* _tmp15_ = NULL;
		BoxesVMCreator* _tmp16_ = NULL;
		BoxesVMCreator* _tmp17_ = NULL;
		BoxesInstallerMedia* _tmp18_ = NULL;
		BoxesInstallerMedia* _tmp19_ = NULL;
		OsinfoOs* _tmp20_ = NULL;
		OsinfoOs* _tmp21_ = NULL;
		gchar* architecture = NULL;
		BoxesLibvirtMachine* _tmp22_ = NULL;
		GVirConfigDomain* _tmp23_ = NULL;
		GVirConfigDomain* _tmp24_ = NULL;
		GVirConfigDomainOs* _tmp25_ = NULL;
		GVirConfigDomainOs* _tmp26_ = NULL;
		const gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		OsinfoOs* _tmp30_ = NULL;
		const gchar* _tmp31_ = NULL;
		OsinfoResources* _tmp32_ = NULL;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = self->priv->machine;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = boxes_libvirt_machine_get_vm_creator (_tmp15_);
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _tmp16_;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = boxes_vm_creator_get_install_media (_tmp17_);
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = _tmp19_->os;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = _g_object_ref0 (_tmp20_);
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		os = _tmp21_;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = self->priv->machine;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = boxes_libvirt_machine_get_domain_config (_tmp22_);
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = _tmp23_;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = gvir_config_domain_get_os (_tmp24_);
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = _tmp25_;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = gvir_config_domain_os_get_arch (_tmp26_);
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = g_strdup (_tmp27_);
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = _tmp28_;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_tmp26_);
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		architecture = _tmp29_;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = os;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = architecture;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = boxes_os_database_get_minimum_resources_for_os (_tmp30_, _tmp31_);
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (minimum_resources);
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		minimum_resources = _tmp32_;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (architecture);
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (os);
#line 6154 "libvirt-machine-properties.c"
	}
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp34_ = minimum_resources;
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp34_ != NULL) {
#line 6160 "libvirt-machine-properties.c"
		OsinfoResources* _tmp35_ = NULL;
		gint64 _tmp36_ = 0LL;
		gint64 _tmp37_ = 0LL;
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp35_ = minimum_resources;
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp36_ = osinfo_resources_get_storage (_tmp35_);
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp37_ = _tmp36_;
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp33_ = _tmp37_ != ((gint64) (-1));
#line 6172 "libvirt-machine-properties.c"
	} else {
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp33_ = FALSE;
#line 6176 "libvirt-machine-properties.c"
	}
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp33_) {
#line 6180 "libvirt-machine-properties.c"
		OsinfoResources* _tmp38_ = NULL;
		gint64 _tmp39_ = 0LL;
		gint64 _tmp40_ = 0LL;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp38_ = minimum_resources;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp39_ = osinfo_resources_get_storage (_tmp38_);
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp40_ = _tmp39_;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = (guint64) _tmp40_;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (minimum_resources);
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 6198 "libvirt-machine-properties.c"
	} else {
		OsinfoResources* default_resources = NULL;
		OsinfoResources* _tmp41_ = NULL;
		GVirStorageVolInfo* _tmp42_ = NULL;
		guint64 _tmp43_ = 0ULL;
		OsinfoResources* _tmp44_ = NULL;
		gint64 _tmp45_ = 0LL;
		gint64 _tmp46_ = 0LL;
		guint64 _tmp47_ = 0ULL;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp41_ = boxes_os_database_get_default_resources ();
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		default_resources = _tmp41_;
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp42_ = volume_info;
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp43_ = _tmp42_->capacity;
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp44_ = default_resources;
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp45_ = osinfo_resources_get_storage (_tmp44_);
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp46_ = _tmp45_;
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp47_ = MIN (_tmp43_, (guint64) _tmp46_);
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = _tmp47_;
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (default_resources);
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (minimum_resources);
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 6234 "libvirt-machine-properties.c"
	}
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (minimum_resources);
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__vala_GVirStorageVolInfo_free0 (volume_info);
#line 6240 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_resize_storage_volume (BoxesLibvirtMachineProperties* self, guint64 size, GError** error) {
	GVirStorageVolInfo* volume_info = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirStorageVol* _tmp1_ = NULL;
	GVirStorageVol* _tmp2_ = NULL;
	GVirStorageVolInfo* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	BoxesLibvirtMachine* _tmp5_ = NULL;
	BoxesVMCreator* _tmp6_ = NULL;
	BoxesVMCreator* _tmp7_ = NULL;
	GError * _inner_error_ = NULL;
#line 605 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_storage_volume (_tmp0_);
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = gvir_storage_vol_get_info (_tmp2_, &_inner_error_);
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	volume_info = _tmp3_;
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 6273 "libvirt-machine-properties.c"
	}
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = self->priv->machine;
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = boxes_libvirt_machine_get_vm_creator (_tmp5_);
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = _tmp6_;
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp7_ != NULL) {
#line 6283 "libvirt-machine-properties.c"
		guint64 _tmp8_ = 0ULL;
		GVirStorageVolInfo* _tmp9_ = NULL;
		guint64 _tmp10_ = 0ULL;
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = size;
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = volume_info;
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_->capacity;
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = _tmp8_ < _tmp10_;
#line 6295 "libvirt-machine-properties.c"
	} else {
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = FALSE;
#line 6299 "libvirt-machine-properties.c"
	}
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp4_) {
#line 6303 "libvirt-machine-properties.c"
		GVirConfigStorageVol* config = NULL;
		BoxesLibvirtMachine* _tmp11_ = NULL;
		GVirStorageVol* _tmp12_ = NULL;
		GVirStorageVol* _tmp13_ = NULL;
		GVirConfigStorageVol* _tmp14_ = NULL;
		GVirConfigStorageVol* _tmp15_ = NULL;
		guint64 _tmp16_ = 0ULL;
		BoxesLibvirtMachine* _tmp17_ = NULL;
		GVirStorageVol* _tmp18_ = NULL;
		GVirStorageVol* _tmp19_ = NULL;
		GVirStoragePool* pool = NULL;
		BoxesLibvirtMachine* _tmp20_ = NULL;
		GVirConnection* _tmp21_ = NULL;
		GVirConnection* _tmp22_ = NULL;
		GVirStoragePool* _tmp23_ = NULL;
		GVirStorageVol* _tmp24_ = NULL;
		GVirStoragePool* _tmp25_ = NULL;
		GVirConfigStorageVol* _tmp26_ = NULL;
		GVirStorageVol* _tmp27_ = NULL;
		BoxesLibvirtMachine* _tmp28_ = NULL;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = self->priv->machine;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = boxes_libvirt_machine_get_storage_volume (_tmp11_);
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = _tmp12_;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = gvir_storage_vol_get_config (_tmp13_, (guint) GVIR_DOMAIN_XML_NONE, &_inner_error_);
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp14_;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_propagate_error (error, _inner_error_);
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 6342 "libvirt-machine-properties.c"
		}
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = config;
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = size;
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_storage_vol_set_capacity (_tmp15_, _tmp16_);
#line 611 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = self->priv->machine;
#line 611 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = boxes_libvirt_machine_get_storage_volume (_tmp17_);
#line 611 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 611 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_storage_vol_delete (_tmp19_, (guint) 0, &_inner_error_);
#line 611 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 611 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_propagate_error (error, _inner_error_);
#line 611 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 611 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 611 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 6368 "libvirt-machine-properties.c"
		}
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = self->priv->machine;
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = boxes_libvirt_machine_get_connection (_tmp20_);
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = _tmp21_;
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = boxes_get_storage_pool (_tmp22_);
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		pool = _tmp23_;
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = pool;
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = config;
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = gvir_storage_pool_create_volume (_tmp25_, _tmp26_, &_inner_error_);
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = _tmp27_;
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_propagate_error (error, _inner_error_);
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (pool);
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 6400 "libvirt-machine-properties.c"
		}
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = self->priv->machine;
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_set_storage_volume (_tmp28_, _tmp24_);
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_tmp24_);
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (pool);
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 6412 "libvirt-machine-properties.c"
	} else {
		BoxesLibvirtMachine* _tmp29_ = NULL;
		GVirStorageVol* _tmp30_ = NULL;
		GVirStorageVol* _tmp31_ = NULL;
		guint64 _tmp32_ = 0ULL;
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = self->priv->machine;
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = boxes_libvirt_machine_get_storage_volume (_tmp29_);
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = _tmp30_;
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = size;
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_storage_vol_resize (_tmp31_, _tmp32_, GVIR_STORAGE_VOL_RESIZE_NONE, &_inner_error_);
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_propagate_error (error, _inner_error_);
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 6436 "libvirt-machine-properties.c"
		}
	}
#line 605 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__vala_GVirStorageVolInfo_free0 (volume_info);
#line 6441 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_class_init (BoxesLibvirtMachinePropertiesClass * klass) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_type_class_add_private (klass, sizeof (BoxesLibvirtMachinePropertiesPrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_libvirt_machine_properties_finalize;
#line 6452 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_boxes_iproperties_provider_interface_init (BoxesIPropertiesProviderIface * iface) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_boxes_iproperties_provider_parent_iface = g_type_interface_peek_parent (iface);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	iface->get_properties = (GList* (*)(BoxesIPropertiesProvider*, BoxesPropertiesPage, PropertyCreationFlag*)) boxes_libvirt_machine_properties_real_get_properties;
#line 6461 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_instance_init (BoxesLibvirtMachineProperties * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self->priv = BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_PRIVATE (self);
#line 6468 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_finalize (GObject* obj) {
	BoxesLibvirtMachineProperties * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachineProperties);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	G_OBJECT_CLASS (boxes_libvirt_machine_properties_parent_class)->finalize (obj);
#line 6478 "libvirt-machine-properties.c"
}


GType boxes_libvirt_machine_properties_get_type (void) {
	static volatile gsize boxes_libvirt_machine_properties_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_libvirt_machine_properties_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesLibvirtMachinePropertiesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_libvirt_machine_properties_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesLibvirtMachineProperties), 0, (GInstanceInitFunc) boxes_libvirt_machine_properties_instance_init, NULL };
		static const GInterfaceInfo boxes_iproperties_provider_info = { (GInterfaceInitFunc) boxes_libvirt_machine_properties_boxes_iproperties_provider_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_libvirt_machine_properties_type_id;
		boxes_libvirt_machine_properties_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesLibvirtMachineProperties", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_libvirt_machine_properties_type_id, BOXES_TYPE_IPROPERTIES_PROVIDER, &boxes_iproperties_provider_info);
		g_once_init_leave (&boxes_libvirt_machine_properties_type_id__volatile, boxes_libvirt_machine_properties_type_id);
	}
	return boxes_libvirt_machine_properties_type_id__volatile;
}



